package com.mbridge.sdk.demo;

import android.content.Intent;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ListView;
import android.widget.TextView;

import com.mbridge.msdk.out.MBConfiguration;
import com.mbridge.sdk.demo.adapter.CommonAdapter;
import com.mbridge.sdk.demo.adapter.ViewHolder;
import com.mbridge.sdk.demo.bean.AdStyleInfoBean;
import com.mbridge.sdk.demo.bid.BidChoiceActivity;

import java.util.ArrayList;
import java.util.List;

public class HomeActivity extends BaseActivity {

	private static final String TAG = HomeActivity.class.getName();

	private static final int POSITION_NATIVE = 0;
	private static final int POSITION_REWARDVIDEO = 1;
	private static final int POSITION_INTERSTITIAL = 2;
	private static final int POSITION_INTERSTITIAL_VIDEO = 3;
	private static final int POSITION_BID = 4;
	private static final int POSITION_SPLASH = 5;
	private static final int POSITION_BANNER = 6;
	private static final int POSITION_ADVANCED_NATIVE = 7;
	private static final int POSITION_NEW_INTERSTITIAL = 8;

	private ListView mLvAdList;
	private TextView mVersion;

	@Override
	public int getResLayoutId() {
		return R.layout.mbridge_demo_atv_home;
	}

	@Override
	public void initView() {
		mLvAdList = (ListView) findViewById(R.id.mbridge_demo_lv_ad_list);
		mVersion = (TextView) findViewById(R.id.title_version);
	}

	@Override
	public void initData() {
		String version = MBConfiguration.SDK_VERSION;
		String[] v = version.split("_");
		mVersion.setText(v[1]);
		List<AdStyleInfoBean> adStyleLists = new ArrayList<AdStyleInfoBean>();
		AdStyleInfoBean bidStyle = new AdStyleInfoBean("Header bidding", R.drawable.mbridge_demo_ad_hb,
				R.drawable.mbridge_demo_icon_hb);
		AdStyleInfoBean nativeStyle = new AdStyleInfoBean("Native", R.drawable.mbridge_demo_ad_native,
				R.drawable.mbridge_demo_icon_native);
		AdStyleInfoBean rewardStyle = new AdStyleInfoBean("RewardVideo", R.drawable.mbridge_demo_ad_reward,
				R.drawable.mbridge_demo_icon_reward);
		AdStyleInfoBean intersititialStyle = new AdStyleInfoBean("Interstitial", R.drawable.mbridge_demo_ad_interstitial,
				R.drawable.mbridge_demo_icon_intertitial);
		AdStyleInfoBean intersititialVideoStyle = new AdStyleInfoBean("InterstitialVideo", R.drawable.mbridge_demo_ad_interstitial_video,
				R.drawable.mbridge_demo_icon_interstitial_video);
		AdStyleInfoBean bannerStyle = new AdStyleInfoBean("Banner", R.drawable.mbridge_demo_ad_banner,
				R.drawable.mbridge_demo_icon_splash);
		AdStyleInfoBean splashStyle = new AdStyleInfoBean("Splash", R.drawable.mbridge_demo_ad_splash,
				R.drawable.mbridge_demo_icon_splash);
		AdStyleInfoBean advancedNativeStyle = new AdStyleInfoBean("AdvancedNative", R.drawable.mbridge_demo_ad_native_advanced,
				R.drawable.mbridge_demo_icon_native_advanced);
		AdStyleInfoBean newInterstitialStyle = new AdStyleInfoBean("New Interstitial", R.drawable.mbridge_demo_ad_new_interstitial,
				R.drawable.mbridge_demo_icon_new_interstitial);

		adStyleLists.add(nativeStyle);
		adStyleLists.add(rewardStyle);
		adStyleLists.add(intersititialStyle);
		adStyleLists.add(intersititialVideoStyle);
		adStyleLists.add(bidStyle);
		adStyleLists.add(splashStyle);
		adStyleLists.add(bannerStyle);
		adStyleLists.add(advancedNativeStyle);
		adStyleLists.add(newInterstitialStyle);
		CommonAdapter<AdStyleInfoBean> adapter = new CommonAdapter<AdStyleInfoBean>(adStyleLists,
				R.layout.mbridge_demo_item_ad_style, this) {

			@Override
			public void convert(ViewHolder helper, AdStyleInfoBean item) {
				helper.setText(R.id.mbridge_demo_item_tv_ad_name, item.getAdStyleName());
				helper.setImageResource(R.id.mbridge_demo_item_iv_big, item.getAdImageResId());
				helper.setImageResource(R.id.mbridge_demo_item_iv_icon, item.getAdIconResId());
			}
		};
		mLvAdList.setAdapter(adapter);
	}

	@Override
	public void setListener() {
		mLvAdList.setOnItemClickListener(new OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
				Intent intent;
				switch (position) {
					case POSITION_BID:
						intent = new Intent(HomeActivity.this, BidChoiceActivity.class);
						startActivity(intent);
						break;
					case POSITION_NATIVE:
						intent = new Intent(HomeActivity.this, NativeChoiceActivity.class);
						startActivity(intent);
						break;
					case POSITION_REWARDVIDEO:
						intent = new Intent(HomeActivity.this, RewardActivity.class);
						startActivity(intent);
						break;
					case POSITION_INTERSTITIAL:
						intent = new Intent(HomeActivity.this, InterstitialActivity.class);
						startActivity(intent);
						break;
					case POSITION_INTERSTITIAL_VIDEO:
						intent = new Intent(HomeActivity.this, InterstitialVideoActivity.class);
						startActivity(intent);
						break;
					case POSITION_SPLASH:
						intent = new Intent(HomeActivity.this, SplashActivity.class);
						startActivity(intent);
						break;
					case POSITION_BANNER:
						intent = new Intent(HomeActivity.this, BannerActivity.class);
						startActivity(intent);
						break;
					case POSITION_ADVANCED_NATIVE:
						intent = new Intent(HomeActivity.this, NativeAdvancedShowActivity.class);
						startActivity(intent);
						break;
					case POSITION_NEW_INTERSTITIAL:
						intent = new Intent(HomeActivity.this, NewInterstitialActivity.class);
						startActivity(intent);
						break;
					default:
						break;
				}
			}
		});
	}


}
