package com.mbridge.sdk.demo;

import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.ProgressBar;
import android.widget.Toast;

import com.mbridge.msdk.MBridgeConstans;
import com.mbridge.msdk.out.InterstitialListener;
import com.mbridge.msdk.out.MBInterstitialHandler;
import com.mbridge.msdk.out.MBridgeIds;
import com.mbridge.sdk.demo.view.CommonTitleLayout;

import java.util.HashMap;

public class InterstitialActivity extends BaseActivity implements OnClickListener {

	public static final String TAG = "InterstitialActivity";
	private Button mBtPreLoad;
	private Button mBtShow;
	private MBInterstitialHandler mInterstitialHandler;
	private CommonTitleLayout mTitleLayout;
	private ProgressBar mProgressBar;

	@Override
	public int getResLayoutId() {
		return R.layout.mbridge_demo_atv_interstitial;
	}

	@Override
	public void initView() {
		mBtPreLoad = (Button) findViewById(R.id.bt_preload);
		mBtShow = (Button) findViewById(R.id.bt_show);
		mProgressBar = (ProgressBar) findViewById(R.id.mbridge_demo_progress);
		mTitleLayout = (CommonTitleLayout) findViewById(R.id.mbridge_demo_common_title_layout);
	}

	@Override
	public void initData() {
		mTitleLayout.setTitleText("Intertitial");
		initHandler();
	}

	private void showLoadding() {
		mProgressBar.setVisibility(View.VISIBLE);
	}

	private void hideLoadding() {
		mProgressBar.setVisibility(View.GONE);
	}

	@Override
	public void setListener() {
		mBtPreLoad.setOnClickListener(this);
		mBtShow.setOnClickListener(this);
	}

	private void initHandler() {
		HashMap<String, Object> hashMap = new HashMap<String, Object>();
		hashMap.put(MBridgeConstans.PROPERTIES_UNIT_ID, "146871");
		hashMap.put(MBridgeConstans.PLACEMENT_ID, "138783");
		mInterstitialHandler = new MBInterstitialHandler(this, hashMap);
		mInterstitialHandler.setInterstitialListener(new InterstitialListener() {
			@Override
			public void onInterstitialShowSuccess(MBridgeIds ids) {
				Log.e(TAG, "onInterstitialShowSuccess: " + ids.toString());
			}

			@Override
			public void onInterstitialShowFail(MBridgeIds ids, String errorMsg) {
				Log.e(TAG, "onInterstitialShowFail: " + errorMsg + " " + ids.toString());
			}

			@Override
			public void onInterstitialLoadSuccess(MBridgeIds ids) {
				Log.e(TAG, "onInterstitialLoadSuccess: " + ids.toString());
				hideLoadding();
				Toast.makeText(getApplicationContext(), "onInterstitialLoadSuccess", Toast.LENGTH_LONG).show();
			}

			@Override
			public void onInterstitialLoadFail(MBridgeIds ids, String errorMsg) {
				Log.e(TAG, "onInterstitialLoadFail: " + errorMsg + " " + ids.toString());
			}

			@Override
			public void onInterstitialClosed(MBridgeIds ids) {
				Log.e(TAG, "onInterstitialClosed: " + ids.toString());
			}

			@Override
			public void onInterstitialAdClick(MBridgeIds ids) {
				Log.e(TAG, "onInterstitialAdClick: " + ids.toString());
			}
		});
	}

	@Override
	public void onClick(View v) {
		switch (v.getId()) {
		case R.id.bt_preload:

			if (mInterstitialHandler != null) {
				showLoadding();
				mInterstitialHandler.preload();
			}
			break;
		case R.id.bt_show:

			if (mInterstitialHandler != null) {
				mInterstitialHandler.show();
			}
			break;
		}
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		if(mInterstitialHandler != null){
			mInterstitialHandler.setInterstitialListener(null);
		}
	}
}
