package com.mbridge.sdk.demo;

import android.app.ActivityManager;
import android.app.Application;
import android.content.Context;
import android.content.res.Configuration;
import android.os.Build;
import android.os.StrictMode;
import android.util.DisplayMetrics;
import android.util.Log;
import android.webkit.WebView;

import androidx.annotation.RequiresApi;

import com.squareup.leakcanary.LeakRefWatcherBuilderNoToast;
import com.squareup.leakcanary.LeakCanaryNoDisplay;
import com.squareup.leakcanary.LeakNotifyService;
import com.tencent.bugly.crashreport.CrashReport;

public class MainApplication extends Application {

    @RequiresApi(api = Build.VERSION_CODES.P)
    @Override
    public void onCreate() {

        super.onCreate();
        CrashReport.UserStrategy strategy = new CrashReport.UserStrategy(getApplicationContext());
        strategy.setDeviceModel(Build.MODEL);
        strategy.setAppReportDelay(10000);
        CrashReport.initCrashReport(getApplicationContext(), "e4999d3b1b", false, strategy);
        CrashReport.setUserSceneTag(this, 218810);

        // 安装LeakCanary
        LeakRefWatcherBuilderNoToast refBuilder = LeakCanaryNoDisplay.refWatcher(getApplicationContext());
        refBuilder.listenerServiceClass(LeakNotifyService.class);
        refBuilder.maxStoredHeapDumps(20);
        refBuilder.buildAndInstall();
        LeakCanaryNoDisplay.enableDisplayLeakActivity(getApplicationContext());
        initWebViewDataDirectory(this);

        // test appId and appKey
        String appId = "118690";
        String appKey = "7c22942b749fe6a6e361b675e96b3ee9";
        MBridgeSDKManager.getInstance().initialize(getApplicationContext(), appKey, appId, true, null, new MBridgeSDKManager.MBridgeSDKInitializeListener() {
            @Override
            public void onInitializeSuccess(String appKey, String appID) {
                Log.e("SDKInitStatus", "onInitSuccess");
            }

            @Override
            public void onInitializeFailure(String message) {
                Log.e("SDKInitStatus", "onInitFail");
            }
        });
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        DisplayMetrics dm = this.getBaseContext().getResources().getDisplayMetrics();
        this.getBaseContext().getResources().updateConfiguration(newConfig, dm);
    }

    /**
     * 得到进程名称
     *
     * @return
     */
    public static String getProcessName(Context context) {
        try {
            if (context == null)
                return null;
            ActivityManager manager = (ActivityManager)
                    context.getSystemService(Context.ACTIVITY_SERVICE);
            for (ActivityManager.RunningAppProcessInfo processInfo :
                    manager.getRunningAppProcesses()) {
                if (processInfo.pid == android.os.Process.myPid()) {
                    return processInfo.processName;
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 为webView设置目录后缀
     */
    @RequiresApi(api = Build.VERSION_CODES.P)
    public static void initWebViewDataDirectory(Context context) {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
            String processName = getProcessName(context);
            if (processName != null && !context.getPackageName().equals(processName)) {//判断是否是默认进程名称
                WebView.setDataDirectorySuffix(processName);
            }
        }
    }
}
