package com.mbridge.sdk.demo;

import android.graphics.drawable.Drawable;
import android.text.TextUtils;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemSelectedListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.Spinner;
import android.widget.TextView;

import com.mbridge.msdk.MBridgeConstans;
import com.mbridge.msdk.MBridgeSDK;
import com.mbridge.msdk.out.Campaign;
import com.mbridge.msdk.out.Frame;
import com.mbridge.msdk.out.MBNativeHandler;
import com.mbridge.msdk.out.MBridgeSDKFactory;
import com.mbridge.msdk.out.NativeListener.NativeAdListener;
import com.mbridge.msdk.out.NativeListener.NativeTrackingListener;
import com.mbridge.msdk.widget.MBAdChoice;
import com.mbridge.sdk.demo.util.ImageLoadTask;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class NativeActivity extends BaseActivity implements OnClickListener {
    private static final String TAG = NativeActivity.class.getName();

    private Button mBtNative;
    private Button mBtPreloadNative;
    private Spinner mSpinner;
    private static final String sMBAdSouceUnitID = "146868";

    public int AD_NUM = 1;
    private String mCurrentUnitId = "";

    private MBNativeHandler mNativeHandle;
    private Campaign mCampaign;
    private FrameLayout mFlAdHolder;
    private TextView mTvTitle;
    private ImageView mIvDisplayArea;

    @Override
    public int getResLayoutId() {
        return R.layout.mbridge_demo_atv_native;
    }

    @Override
    public void initView() {
        mBtPreloadNative = (Button) findViewById(R.id.btPreNative);
        mBtNative = (Button) findViewById(R.id.btNative);
        mTvTitle = (TextView) findViewById(R.id.mbridge_demo_tv_title);
        mFlAdHolder = (FrameLayout) findViewById(R.id.fl_adplaceholder);
        mSpinner = (Spinner) findViewById(R.id.mbridge_demo_native_sp);
        mIvDisplayArea = (ImageView) findViewById(R.id.mbridge_demo_iv_display_area);

    }

    @Override
    public void initData() {
        mTvTitle.setText("NATIVE");
        List<String> adSourceList = new ArrayList<String>();
        adSourceList.add("MB");
        ArrayAdapter<String> adSouceAdapter = new ArrayAdapter<String>(this, R.layout.mbridge_demo_native_sp_display,
                R.id.mbridge_demo_tv_sp_name, adSourceList);
        adSouceAdapter.setDropDownViewResource(R.layout.mbridge_demo_sp_dropdown_adsouce);
        mSpinner.setAdapter(adSouceAdapter);
    }

    @Override
    public void setListener() {
        mTvTitle.setOnClickListener(this);
        mBtPreloadNative.setOnClickListener(this);
        mBtNative.setOnClickListener(this);
        mSpinner.setOnItemSelectedListener(new OnItemSelectedListener() {

            @Override
            public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
                setUnitId(position);
            }

            @Override
            public void onNothingSelected(AdapterView<?> parent) {

            }
        });

    }

    private void setUnitId(int position) {
        switch (position) {
            default:
                mCurrentUnitId = sMBAdSouceUnitID;
                break;
        }
    }


    public void preloadNative() {

        MBridgeSDK sdk = MBridgeSDKFactory.getMBridgeSDK();
        Map<String, Object> preloadMap = new HashMap<String, Object>();
        preloadMap.put(MBridgeConstans.PROPERTIES_LAYOUT_TYPE, MBridgeConstans.LAYOUT_NATIVE);
        preloadMap.put(MBridgeConstans.PROPERTIES_UNIT_ID, mCurrentUnitId);
        preloadMap.put(MBridgeConstans.PLACEMENT_ID, "138780");

        preloadMap.put(MBridgeConstans.PROPERTIES_AD_NUM, AD_NUM);
        preloadMap.put(MBridgeConstans.PREIMAGE, true);
        sdk.preload(preloadMap);

    }

    public void loadNative() {
        Map<String, Object> properties = MBNativeHandler.getNativeProperties("138780", mCurrentUnitId);
        properties.put(MBridgeConstans.PROPERTIES_AD_NUM, AD_NUM);
        mNativeHandle = new MBNativeHandler(properties, this);
        mNativeHandle.setAdListener(new NativeAdListener() {

            @Override
            public void onAdLoaded(List<Campaign> campaigns, int template) {
                Log.e(TAG, "onAdLoaded");
                if (campaigns != null && campaigns.size() > 0) {
                    mIvDisplayArea.setVisibility(View.GONE);
                    mCampaign = campaigns.get(0);
                    for (Campaign campaign : campaigns) {
                        Log.i(TAG, campaign.getAppName());
                    }
                    fillMBAdLayout();
                    preloadNative();
                }
            }

            private void fillMBAdLayout() {
                final View view = LayoutInflater.from(NativeActivity.this)
                        .inflate(R.layout.mbridge_demo_mul_big_ad_content, null);
                final ImageView iv = (ImageView) view.findViewById(R.id.mbridge_demo_iv_image);
                if (!TextUtils.isEmpty(mCampaign.getImageUrl())) {
                    new ImageLoadTask(mCampaign.getImageUrl()) {

                        @Override
                        public void onRecived(Drawable result) {
                            iv.setImageDrawable(result);
                            mNativeHandle.registerView(view, mCampaign);
                        }
                    }.execute();
                }
                TextView tvAppName = (TextView) view.findViewById(R.id.mbridge_demo_bt_app_name);
                MBAdChoice mbAdChoice = view.findViewById(R.id.mbridge_demo_native_adchoice);
                int height = mCampaign.getAdchoiceSizeHeight();
                int width = mCampaign.getAdchoiceSizeWidth();
                ViewGroup.LayoutParams layoutParams = mbAdChoice.getLayoutParams();
                layoutParams.width = width;
                layoutParams.height = height;
                mbAdChoice.setLayoutParams(layoutParams);
                mbAdChoice.setCampaign(mCampaign);
                tvAppName.setText(mCampaign.getAppName());
                mFlAdHolder.removeAllViews();
                mFlAdHolder.addView(view);
            }

            @Override
            public void onAdLoadError(String message) {
                Log.e(TAG, "onAdLoadError" + message);
            }

            @Override
            public void onAdClick(Campaign campaign) {
                Log.e(TAG, "onAdClick");
            }

            @Override
            public void onAdFramesLoaded(final List<Frame> list) {

            }

            @Override
            public void onLoggingImpression(int adsourceType) {
                Log.e(TAG, "onLoggingImpression adsourceType:" + adsourceType);
            }
        });

        mNativeHandle.setTrackingListener(new NativeTrackingListener() {

            @Override
            public void onStartRedirection(Campaign campaign, String url) {
                Log.e(TAG, "onStartRedirection---");
            }

            @Override
            public void onRedirectionFailed(Campaign campaign, String url) {
                Log.e(TAG, "onRedirectionFailed---");
            }

            @Override
            public void onFinishRedirection(Campaign campaign, String url) {
                Log.e(TAG, "onFinishRedirection---" + url);
            }

            @Override
            public void onDownloadStart(Campaign campaign) {
                Log.e(TAG, "start---");
            }

            @Override
            public void onDownloadFinish(Campaign campaign) {
                Log.e(TAG, "finish---");

            }

            @Override
            public void onDownloadProgress(int progress) {
                Log.e(TAG, "progress----" + progress);
            }

            @Override
            public boolean onInterceptDefaultLoadingDialog() {
                return false;
            }

            @Override
            public void onShowLoading(Campaign campaign) {

            }

            @Override
            public void onDismissLoading(Campaign campaign) {

            }
        });
        mNativeHandle.load();
    }

    @Override
    public void onClick(View v) {
        int id = v.getId();
        switch (id) {
            case R.id.btPreNative:
                preloadNative();
                break;
            case R.id.btNative:
                loadNative();
                break;
            case R.id.mbridge_demo_tv_title:
                finish();
                break;
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mNativeHandle != null) {
            mNativeHandle.release();
        }
    }

}