package com.mbridge.sdk.demo;

import android.app.Activity;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.RelativeLayout;
import android.widget.Toast;

import com.mbridge.msdk.MBridgeConstans;
import com.mbridge.msdk.out.AutoPlayMode;
import com.mbridge.msdk.out.MBMultiStateEnum;
import com.mbridge.msdk.out.MBNativeAdvancedHandler;
import com.mbridge.msdk.out.MBridgeIds;
import com.mbridge.msdk.out.MBridgeSDKFactory;
import com.mbridge.msdk.out.NativeAdvancedAdListener;

import org.json.JSONObject;

import java.lang.ref.WeakReference;

public class NativeAdvancedShowActivity extends BaseActivity implements View.OnClickListener {
    private static String TAG = "AdvancedNativeActivity";

    private RelativeLayout container;
    private Button preloadBtn;
    private Button showBtn;
    private Button releaseBtn;

    private String placementId = "202132";
    private String mUnitId= "258656";
    private int advancedNativeH = 640;
    private int advancedNativeW = 320;
    private MBNativeAdvancedHandler mbNativeAdvancedHandler;
    private ViewGroup mAdvancedNativeView;

    @Override
    public int getResLayoutId() {
        return R.layout.mbridge_demo_native_advanced_activity;
    }

    @Override
    public void initView() {
        container = findViewById(R.id.mbridge_demo_advanced_native_ac_container);
        preloadBtn = findViewById(R.id.mbridge_demo_advanced_native_ac_preload);
        showBtn = findViewById(R.id.mbridge_demo_advanced_native_ac_show);
        releaseBtn = findViewById(R.id.mbridge_demo_advanced_native_ac_release);
    }

    @Override
    public void initData() {
        try {
            mbNativeAdvancedHandler = new MBNativeAdvancedHandler(this,placementId, mUnitId);
            mbNativeAdvancedHandler.setNativeViewSize(advancedNativeW,advancedNativeH);
            mbNativeAdvancedHandler.setCloseButtonState(MBMultiStateEnum.positive);
            mbNativeAdvancedHandler.setPlayMuteState(MBridgeConstans.REWARD_VIDEO_PLAY_MUTE);
            mbNativeAdvancedHandler.autoLoopPlay(AutoPlayMode.PLAY_WHEN_NETWORK_IS_AVAILABLE);
            String style = "{\"list\": [{\n" +
                    "\"target\": \"title\",\n" +
                    "\"values\": {\n" +
                    "\"paddingLeft\": 15,\"backgroundColor\": \"yellow\",\n" +
                    "                    \"fontSize\": 15,\n" +
                    "                    \"color\": \"red\"\n" +
                    "                  }\n" +
                    "              },{\n" +
                    "                  \"target\": \"mediaContent\",\n" +
                    "\n" +
                    "                  \"values\": {\n" +
                    "                      \"paddingLeft\": 60\n" +
                    "                  }\n" +
                    "              }]\n" +
                    "            }";
            JSONObject jsonObject = new JSONObject(style);
            mbNativeAdvancedHandler.setViewElementStyle(jsonObject);
            mAdvancedNativeView = mbNativeAdvancedHandler.getAdViewGroup();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public void setListener() {
        mbNativeAdvancedHandler.setAdListener(new NativeAdvancedAdListener() {
            @Override
            public void onLoadSuccessed(MBridgeIds ids) {
                Log.e(TAG, "onLoadSuccessed: " + ids.toString());
                Toast.makeText(NativeAdvancedShowActivity.this,"onLoadSuccessed:",Toast.LENGTH_LONG).show();
            }

            @Override
            public void onLoadFailed(MBridgeIds ids, String msg) {
                Log.e(TAG, "onLoadFailed: " + msg + "  " + ids.toString());
                Toast.makeText(NativeAdvancedShowActivity.this,"onLoadFailed:" ,Toast.LENGTH_LONG).show();
            }

            @Override
            public void onLogImpression(MBridgeIds ids) {
                Log.e(TAG, "onLogImpression: " + ids.toString() );
                Toast.makeText(NativeAdvancedShowActivity.this,"onLogImpression:" ,Toast.LENGTH_LONG).show();
            }

            @Override
            public void onClick(MBridgeIds ids) {
                Log.e(TAG, "onClick: " + ids.toString() );
                Toast.makeText(NativeAdvancedShowActivity.this,"onClick:" ,Toast.LENGTH_LONG).show();
            }

            @Override
            public void onLeaveApp(MBridgeIds ids) {
                Log.e(TAG, "onLeaveApp: " + ids.toString() );
                Toast.makeText(NativeAdvancedShowActivity.this,"onLeaveApp:" ,Toast.LENGTH_LONG).show();
            }

            @Override
            public void showFullScreen(MBridgeIds ids) {
                Log.e(TAG, "showFullScreen: " + ids.toString() );
                Toast.makeText(NativeAdvancedShowActivity.this,"showFullScreen:" ,Toast.LENGTH_LONG).show();
            }

            @Override
            public void closeFullScreen(MBridgeIds ids) {
                Log.e(TAG, "closeFullScreen: " + ids.toString() );
                Toast.makeText(NativeAdvancedShowActivity.this,"closeFullScreen:" ,Toast.LENGTH_LONG).show();
            }

            @Override
            public void onClose(MBridgeIds ids) {
                Log.e(TAG, "onDismiss: " + ids.toString() );
                Toast.makeText(NativeAdvancedShowActivity.this,"onDismiss:" ,Toast.LENGTH_LONG).show();
            }
        });

        preloadBtn.setOnClickListener(this);
        showBtn.setOnClickListener(this);
        releaseBtn.setOnClickListener(this);
    }

    private void show(){
        MBridgeSDKFactory.getMBridgeSDK().updateDialogWeakActivity(new WeakReference<Activity>(this));
        if (mAdvancedNativeView != null && mAdvancedNativeView.getParent() == null) {
            container.addView(mAdvancedNativeView);
        }
    }


    @Override
    protected void onResume() {
        super.onResume();
        if(mbNativeAdvancedHandler != null){
            mbNativeAdvancedHandler.onResume();
        }
    }

    @Override
    protected void onPause() {
        super.onPause();
        if(mbNativeAdvancedHandler != null){
            mbNativeAdvancedHandler.onPause();
        }
    }

    @Override
    protected void onDestroy() {
        if(mbNativeAdvancedHandler != null){
            mbNativeAdvancedHandler.release();
        }
        super.onDestroy();
    }



    @Override
    public void onClick(View v) {
        switch (v.getId()){
            case R.id.mbridge_demo_advanced_native_ac_preload:
                mbNativeAdvancedHandler.load();
                break;
            case R.id.mbridge_demo_advanced_native_ac_show:
                show();
                break;
            case R.id.mbridge_demo_advanced_native_ac_release:
                mbNativeAdvancedHandler.release();
                break;
        }
    }
}
