package com.mbridge.sdk.demo;

import android.graphics.drawable.Drawable;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemSelectedListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.GridView;
import android.widget.ImageView;
import android.widget.Spinner;
import android.widget.TextView;

import com.mbridge.msdk.MBridgeConstans;
import com.mbridge.msdk.MBridgeSDK;
import com.mbridge.msdk.out.Campaign;
import com.mbridge.msdk.out.Frame;
import com.mbridge.msdk.out.MBNativeHandler;
import com.mbridge.msdk.out.MBridgeSDKFactory;
import com.mbridge.msdk.out.NativeListener.NativeAdListener;
import com.mbridge.msdk.out.NativeListener.NativeTrackingListener;
import com.mbridge.msdk.out.NativeListener.Template;
import com.mbridge.sdk.demo.adapter.CommonAdapter;
import com.mbridge.sdk.demo.adapter.ViewHolder;
import com.mbridge.sdk.demo.util.ImageLoadTask;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class NativeMultemplateActivity extends BaseActivity implements OnClickListener {
	protected static final String TAG = NativeMultemplateActivity.class.getName();
	private Button mBtNative;
	private Button mBtnPreloadNative;
	private Spinner mSpinner;
	private static final String sMBAdSouceUnitID = "146868";
	private String mCurrentUnitId = "";

	public int BIG_IMG_REQUEST_AD_NUM = 1;
	public int MULTIPLE_IMG_REQUEST_AD_NUM = 3;
	public int AD_NUM = 1;
	MBNativeHandler mNativeHandler;
	Campaign mCampaign;
	FrameLayout mFlAdHolder;
	private TextView mTvTitle;
	private ImageView mIvDisplayArea;

	private void setUnitId(int position) {
		switch (position) {
		default:
			mCurrentUnitId = sMBAdSouceUnitID;
			break;
		}
	}

	public void preloadNative() {

		MBridgeSDK sdk = MBridgeSDKFactory.getMBridgeSDK();
		Map<String, Object> preloadMap = new HashMap<String, Object>();
		preloadMap.put(MBridgeConstans.PROPERTIES_LAYOUT_TYPE, MBridgeConstans.LAYOUT_NATIVE);
		preloadMap.put(MBridgeConstans.PROPERTIES_UNIT_ID, mCurrentUnitId);
		preloadMap.put(MBridgeConstans.PLACEMENT_ID, "138780");

		List<Template> list = new ArrayList<Template>();
		list.add(new Template(MBridgeConstans.TEMPLATE_BIG_IMG, BIG_IMG_REQUEST_AD_NUM));
		list.add(new Template(MBridgeConstans.TEMPLATE_MULTIPLE_IMG, MULTIPLE_IMG_REQUEST_AD_NUM));
		preloadMap.put(MBridgeConstans.NATIVE_INFO, MBNativeHandler.getTemplateString(list));
		sdk.preload(preloadMap);

	}

	public void loadNative() {
		Map<String, Object> properties = MBNativeHandler.getNativeProperties("138780", mCurrentUnitId);
		if (mNativeHandler == null) {
			mNativeHandler = new MBNativeHandler(properties, this);
		}

		mNativeHandler.addTemplate(new Template(MBridgeConstans.TEMPLATE_BIG_IMG, BIG_IMG_REQUEST_AD_NUM));
		mNativeHandler.addTemplate(new Template(MBridgeConstans.TEMPLATE_MULTIPLE_IMG, MULTIPLE_IMG_REQUEST_AD_NUM));

		mNativeHandler.setAdListener(new NativeAdListener() {
			@Override
			public void onAdLoaded(List<Campaign> campaigns, int template) {
				if (campaigns != null && campaigns.size() > 0) {
					mIvDisplayArea.setVisibility(View.GONE);
					mCampaign = campaigns.get(0);
					for (Campaign campaign : campaigns) {
						Log.i(" ", campaign.getAppName());
					}
					fillMBAdLayout(campaigns, template);
				}
				Log.e(TAG, "onAdLoaded");
				preloadNative();
			}

			private void fillMBAdLayout(List<Campaign> campaigns, int template) {
				switch (template) {
				case MBridgeConstans.TEMPLATE_BIG_IMG:
					loadMBBigTemplateLayout();
					break;
				case MBridgeConstans.TEMPLATE_MULTIPLE_IMG:
					loadMBMulTemplateLayout(campaigns, template);
					break;
				}
			}

			private void loadMBMulTemplateLayout(List<Campaign> campaigns, int template) {
				if (template == MBridgeConstans.TEMPLATE_MULTIPLE_IMG) {
					View view = LayoutInflater.from(NativeMultemplateActivity.this)
							.inflate(R.layout.mbridge_demo_mul_template_ad_mul_content, null);
					GridView gVMulTemplate = (GridView) view.findViewById(R.id.mbridge_demo_gv_mul_template);
					CommonAdapter<Campaign> adapter = new CommonAdapter<Campaign>(campaigns,
							R.layout.mbridge_demo_mul_template_ad_content, NativeMultemplateActivity.this) {

						@Override
						public void convert(ViewHolder helper, Campaign item) {
							final ImageView iconView = helper.getView(R.id.mbridge_demo_iv_image);
							new ImageLoadTask(item.getIconUrl()) {

								@Override
								public void onRecived(Drawable result) {
									iconView.setImageDrawable(result);
								}
							}.execute();
							helper.setText(R.id.mbridge_demo_bt_app_name, item.getAppName());
							mNativeHandler.registerView(helper.getConvertView(), item);
						}
					};
					gVMulTemplate.setAdapter(adapter);
					mFlAdHolder.removeAllViews();
					mFlAdHolder.addView(view);
				}
			}

			private void loadMBBigTemplateLayout() {
				View view = LayoutInflater.from(NativeMultemplateActivity.this)
						.inflate(R.layout.mbridge_demo_mul_big_ad_content, null);
				final ImageView iv = (ImageView) view.findViewById(R.id.mbridge_demo_iv_image);
				new ImageLoadTask(mCampaign.getImageUrl()) {

					@Override
					public void onRecived(Drawable result) {
						iv.setImageDrawable(result);
					}
				}.execute();
				TextView tvAppName = (TextView) view.findViewById(R.id.mbridge_demo_bt_app_name);
				tvAppName.setText(mCampaign.getAppName());
				mFlAdHolder.removeAllViews();
				mFlAdHolder.addView(view);
				mNativeHandler.registerView(view, mCampaign);
			}

			@Override
			public void onAdLoadError(String message) {
				Log.e(TAG, "onAdLoadError" + message);
			}

			@Override
			public void onAdClick(Campaign campaign) {
				Log.e(TAG, "onAdClick");
			}

			@Override
			public void onAdFramesLoaded(final List<Frame> list) {

			}

			@Override
			public void onLoggingImpression(int adsourceType) {
				Log.e(TAG, "onLoggingImpression");
			}

		});
		mNativeHandler.setTrackingListener(new NativeTrackingListener() {

			@Override
			public void onStartRedirection(Campaign campaign, String url) {

			}

			@Override
			public void onRedirectionFailed(Campaign campaign, String url) {

			}

			@Override
			public void onFinishRedirection(Campaign campaign, String url) {
			}

			@Override
			public void onDownloadStart(Campaign campaign) {
				Log.e(TAG, "start---");
			}

			@Override
			public void onDownloadFinish(Campaign campaign) {
				Log.e(TAG, "finish---");

			}

			@Override
			public void onDownloadProgress(int progress) {
				Log.e(TAG, "progress----" + progress);
			}

			@Override
			public boolean onInterceptDefaultLoadingDialog() {
				return false;
			}

			@Override
			public void onShowLoading(Campaign campaign) {

			}

			@Override
			public void onDismissLoading(Campaign campaign) {

			}
		});

		mNativeHandler.load();

	}

	@Override
	public void onClick(View v) {
		int id = v.getId();
		switch (id) {
		case R.id.btPreNative:
			preloadNative();
			break;
		case R.id.btNative:
			loadNative();
			break;
		case R.id.mbridge_demo_tv_title:
			finish();
			break;
		}
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		if (mNativeHandler != null) {
			mNativeHandler.release();
		}
	}

	@Override
	public int getResLayoutId() {
		return R.layout.mbridge_demo_atv_native;
	}

	@Override
	public void initView() {

		mBtnPreloadNative = (Button) findViewById(R.id.btPreNative);
		mBtNative = (Button) findViewById(R.id.btNative);
		mTvTitle = (TextView) findViewById(R.id.mbridge_demo_tv_title);
		mFlAdHolder = (FrameLayout) findViewById(R.id.fl_adplaceholder);
		mSpinner = (Spinner) findViewById(R.id.mbridge_demo_native_sp);
		mIvDisplayArea = (ImageView) findViewById(R.id.mbridge_demo_iv_display_area);
	}

	@Override
	public void initData() {
		mTvTitle.setText("NATIVE_MUL");
		List<String> adSourceList = new ArrayList<String>();
		adSourceList.add("MB");
		ArrayAdapter<String> adSouceAdapter = new ArrayAdapter<String>(this, R.layout.mbridge_demo_native_sp_display,
				R.id.mbridge_demo_tv_sp_name, adSourceList);
		adSouceAdapter.setDropDownViewResource(R.layout.mbridge_demo_sp_dropdown_adsouce);
		mSpinner.setAdapter(adSouceAdapter);

	}

	@Override
	public void setListener() {
		mTvTitle.setOnClickListener(this);
		mBtNative.setOnClickListener(this);
		mBtnPreloadNative.setOnClickListener(this);
		mSpinner.setOnItemSelectedListener(new OnItemSelectedListener() {

			@Override
			public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
				setUnitId(position);
			}

			@Override
			public void onNothingSelected(AdapterView<?> parent) {

			}
		});
	}

}
