package com.mbridge.sdk.demo;

import android.content.Intent;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.GridView;

import com.mbridge.sdk.demo.adapter.CommonAdapter;
import com.mbridge.sdk.demo.adapter.ViewHolder;
import com.mbridge.sdk.demo.bean.AdStyleInfoBean;
import com.mbridge.sdk.demo.view.CommonTitleLayout;

import java.util.ArrayList;
import java.util.List;

public class NativeSimpleActivity extends BaseActivity {
	private GridView mGvSimpleList;
	private CommonTitleLayout mTitleLayout;
	private static final int POSITION_FEEDS = 0;
	private static final int POSITION_FULL_SCREEN = 1;
	private static final int POSITION_INTERSTITIAL = 2;

	@Override
	public int getResLayoutId() {
		return R.layout.mbridge_native_simple;
	}

	@Override
	public void initView() {
		mGvSimpleList = (GridView) findViewById(R.id.mbridge_demo_gv_simple_list);
		mTitleLayout = (CommonTitleLayout) findViewById(R.id.mbridge_common_demo_title_layout);
	}

	@Override
	public void initData() {
		mTitleLayout.setTitleText("NativeSimple");
		List<AdStyleInfoBean> nativeStyleList = new ArrayList<AdStyleInfoBean>();
		AdStyleInfoBean feedsStyle = new AdStyleInfoBean("FEEDS", R.drawable.mbridge_demo_simple_feeds, 0);
		AdStyleInfoBean fullScreenStyle = new AdStyleInfoBean("FULL SCREEN",
				R.drawable.mbridge_demo_simple_fill_screen, 0);
		AdStyleInfoBean intertitialStyle = new AdStyleInfoBean("INTERTITIAL",
				R.drawable.mbridge_demo_simple_intersitial, 0);

		nativeStyleList.add(feedsStyle);
		nativeStyleList.add(fullScreenStyle);
		nativeStyleList.add(intertitialStyle);
		CommonAdapter<AdStyleInfoBean> adapter = new CommonAdapter<AdStyleInfoBean>(nativeStyleList,
				R.layout.mbridge_demo_item_natives, this) {
			@Override
			public void convert(ViewHolder helper, AdStyleInfoBean item) {
				helper.setImageResource(R.id.mbridge_demo_iv_name, item.getAdImageResId());
				helper.setText(R.id.mbridge_demo_tv_name, item.getAdStyleName());
			}
		};
		mGvSimpleList.setAdapter(adapter);
	}

	@Override
	public void setListener() {
		mGvSimpleList.setOnItemClickListener(new OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
				Intent intent = null;
				switch (position) {
				case POSITION_FEEDS:
					intent = new Intent(NativeSimpleActivity.this, FeedsImageActivity.class);
					startActivity(intent);
					break;
				case POSITION_FULL_SCREEN:
					intent = new Intent(NativeSimpleActivity.this, FullScreenActivity.class);
					startActivity(intent);
					break;
				case POSITION_INTERSTITIAL:
					intent = new Intent(NativeSimpleActivity.this, NativeInterstitialActivity.class);
					startActivity(intent);
					break;
				}
			}
		});
	}

}
