package com.mbridge.sdk.demo;

import android.app.Dialog;
import android.content.IntentFilter;
import android.net.ConnectivityManager;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.mbridge.msdk.MBridgeConstans;
import com.mbridge.msdk.out.MBRewardVideoHandler;
import com.mbridge.msdk.out.MBridgeIds;
import com.mbridge.msdk.out.RewardInfo;
import com.mbridge.msdk.out.RewardVideoListener;
import com.mbridge.msdk.videocommon.download.NetStateOnReceive;
import com.mbridge.sdk.demo.view.CommonTitleLayout;

public class RewardActivity extends BaseActivity implements OnClickListener {
    private final static String TAG = "RewardActivity";
    private Button bt_load;
    private Button bt_show;
    private Button bt_mute;
    private Button bt_unmute;
    private CommonTitleLayout mTitleLayout;
    private MBRewardVideoHandler mMBRewardVideoHandler;
    private ProgressBar mProgressBar;
    private NetStateOnReceive mNetStateOnReceive;
    private Dialog mDialog;
    private String mRewardId = "12817";
    private String mUserId = "123";


    private enum RewardUnit {
        REWARD_UNIT_1("146874", "138786"),
        REWARD_UNIT_2("237149", "");

        private String unitID;
        private String placementID;

        RewardUnit(String unitID, String placementID) {

            this.unitID = unitID;
            this.placementID = placementID;
        }
    }

    private RewardUnit currentRewardUnit = RewardUnit.REWARD_UNIT_1;

    @Override
    public int getResLayoutId() {
        return R.layout.mbridge_demo_atv_reward;
    }

    @Override
    public void initView() {
        bt_load = (Button) findViewById(R.id.bt_load);
        bt_show = (Button) findViewById(R.id.bt_show);
        bt_mute = (Button) findViewById(R.id.bt_mute);
        bt_unmute = (Button) findViewById(R.id.bt_unmute);
        mProgressBar = (ProgressBar) findViewById(R.id.mbridge_demo_progress);
        mTitleLayout = (CommonTitleLayout) findViewById(R.id.mbridge_demo_common_title_layout);
    }

    @Override
    public void initData() {
        initHandler();

    }

    @Override
    public void setListener() {
        mTitleLayout.setTitleText("RewardVideo");
        bt_load.setOnClickListener(this);
        bt_show.setOnClickListener(this);
        bt_mute.setOnClickListener(this);
        bt_unmute.setOnClickListener(this);
    }

    private void showLoadding() {
        mProgressBar.setVisibility(View.VISIBLE);
    }

    private void hideLoadding() {
        mProgressBar.setVisibility(View.GONE);
    }

    private int show = 0;

    private void initHandler() {
        try {
            if (mNetStateOnReceive == null) {
                mNetStateOnReceive = new NetStateOnReceive();
                IntentFilter filter = new IntentFilter();
                filter.addAction(ConnectivityManager.CONNECTIVITY_ACTION);
                registerReceiver(mNetStateOnReceive, filter);
            }

            mMBRewardVideoHandler = MBridgeSDKManager.getInstance().createRewardVideoHandler(this, currentRewardUnit.placementID, currentRewardUnit.unitID);

            mMBRewardVideoHandler.setRewardVideoListener(new RewardVideoListener() {

                @Override
                public void onLoadSuccess(MBridgeIds ids) {
                    Log.e(TAG, "onLoadSuccess: " + (TextUtils.isEmpty(ids.getPlacementId()) ? "" : ids.getPlacementId()) + "  " + ids.getUnitId());
                    Toast.makeText(getApplicationContext(), "onLoadSuccess()", Toast.LENGTH_LONG).show();

                }

                @Override
                public void onVideoLoadSuccess(MBridgeIds ids) {
                    Log.e(TAG, "onVideoLoadSuccess: " + (TextUtils.isEmpty(ids.getPlacementId()) ? "" : ids.getPlacementId()) + "  " + ids.getUnitId());
                    hideLoadding();
                    Toast.makeText(getApplicationContext(), "onVideoLoadSuccess()", Toast.LENGTH_LONG).show();

                }

                @Override
                public void onVideoLoadFail(MBridgeIds ids, String errorMsg) {
                    Log.e(TAG, "onVideoLoadFail: " + errorMsg + "  " + ids.toString());
                    hideLoadding();
                    Toast.makeText(getApplicationContext(), errorMsg, Toast.LENGTH_LONG).show();
                }

                @Override
                public void onShowFail(MBridgeIds ids, String errorMsg) {
                    Log.e(TAG, "onShowFail: " + errorMsg + "  " + ids.toString());
                    Toast.makeText(getApplicationContext(), "errorMsg:" + errorMsg, Toast.LENGTH_LONG).show();
                }

                @Override
                public void onAdShow(MBridgeIds ids) {
                    Log.e(TAG, "onAdShow: " + ids.toString());
                    Toast.makeText(getApplicationContext(), "onAdShow", Toast.LENGTH_LONG).show();
                }

                @Override
                public void onAdClose(MBridgeIds ids, RewardInfo rewardInfo) {
                    Log.e(TAG, "onAdClose : " + ids.toString() + "  " + rewardInfo.toString());
                    Toast.makeText(getApplicationContext(), "onADClose:" + rewardInfo.toString(), Toast.LENGTH_LONG).show();
                }

                @Override
                public void onVideoAdClicked(MBridgeIds ids) {
                    Log.e(TAG, "onVideoAdClicked : " + (TextUtils.isEmpty(ids.getPlacementId()) ? "" : ids.getPlacementId()) + "  " + ids.getUnitId());
                    Toast.makeText(getApplicationContext(), "onVideoAdClicked", Toast.LENGTH_LONG).show();
                }

                @Override
                public void onVideoComplete(MBridgeIds ids) {
                    Log.e(TAG, "onVideoComplete : " + (TextUtils.isEmpty(ids.getPlacementId()) ? "" : ids.getPlacementId()) + "  " + ids.getUnitId());
                    Toast.makeText(getApplicationContext(), "onVideoComplete", Toast.LENGTH_LONG).show();
                }

                @Override
                public void onEndcardShow(MBridgeIds ids) {
                    Log.e(TAG, "onEndcardShow : " + (TextUtils.isEmpty(ids.getPlacementId()) ? "" : ids.getPlacementId()) + "  " + ids.getUnitId());
                    Toast.makeText(getApplicationContext(), "onEndcardShow", Toast.LENGTH_LONG).show();
                }

            });
            mMBRewardVideoHandler.setRewardPlus(true);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.bt_load:
                showLoadding();
                mMBRewardVideoHandler.load();
                break;
            case R.id.bt_show:
                if (mMBRewardVideoHandler.isReady()) {
                    mMBRewardVideoHandler.show(mUserId);
                    //mMBRewardVideoHandler.show();
                    //Extra data will callback at reward ad close.
                    //mMBRewardVideoHandler.show(mUserId, "extra data");
                }
                break;
            case R.id.bt_mute:
                if (mMBRewardVideoHandler != null) {
                    Toast.makeText(getApplicationContext(), "bt_mute", Toast.LENGTH_LONG).show();
                    mMBRewardVideoHandler.playVideoMute(MBridgeConstans.REWARD_VIDEO_PLAY_MUTE);
                }
                break;
            case R.id.bt_unmute:
                if (mMBRewardVideoHandler != null) {
                    Toast.makeText(getApplicationContext(), "bt_unmute", Toast.LENGTH_LONG).show();
                    mMBRewardVideoHandler.playVideoMute(MBridgeConstans.REWARD_VIDEO_PLAY_NOT_MUTE);
                }
                break;
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        try {
            if (mDialog != null) {
                mDialog = null;
            }
            if (mNetStateOnReceive != null) {
                unregisterReceiver(mNetStateOnReceive);
            }
            if (mMBRewardVideoHandler != null) {
                mMBRewardVideoHandler.setRewardVideoListener(null);
            }
            MBridgeSDKManager.getInstance().releaseRewardVideoHandler(currentRewardUnit.unitID);
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    public void showDialog(String RewardName, float RewardAmout) {
        try {
            mDialog = new Dialog(RewardActivity.this);
            View view = View.inflate(RewardActivity.this, R.layout.dialog_reward, null);
            TextView tvRewardName = (TextView) view.findViewById(R.id.tv_rewardName);
            TextView tvRewardAmout = (TextView) view.findViewById(R.id.tv_RewardAmout);
            tvRewardName.setText(RewardName + "");
            tvRewardAmout.setText(RewardAmout + "");
            mDialog.setContentView(view);
            mDialog.show();
        } catch (Throwable t) {
            t.printStackTrace();
        }
    }
}
