package com.mbridge.sdk.demo.bid;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.ProgressBar;
import android.widget.RelativeLayout;
import android.widget.Toast;

import com.mbridge.msdk.mbbid.out.BannerBidRequestParams;
import com.mbridge.msdk.mbbid.out.BidListennning;
import com.mbridge.msdk.mbbid.out.BidManager;
import com.mbridge.msdk.mbbid.out.BidResponsed;
import com.mbridge.msdk.out.BannerAdListener;
import com.mbridge.msdk.out.BannerSize;
import com.mbridge.msdk.out.MBBannerView;
import com.mbridge.msdk.out.MBridgeIds;
import com.mbridge.sdk.demo.BaseActivity;
import com.mbridge.sdk.demo.R;

public class BidBannerActivity extends BaseActivity {

	private static final String TAG = BidBannerActivity.class.getName();
	public static final String UNIT_ID = "146879";
	private ProgressBar mProgressBar;
	private MBBannerView mbBannerView;
	private Button bidBtn,loadBtn;
	private BidManager manager;
	private String bidToken;
	private int bannerH = 720;
	private int bannerW = 1294;
	private AlertDialog sizeChoice;
	private int checkedItem = 0;
	private int checked = 0;
	private CheckBox refresh;
	private CheckBox close;
	private BannerSize bannerSize;
	private final String MINI_SIZE = "320x50";
	private final String MEDIUM_SIZE = "300x250";
	private final String BIG_SIZE = "320x90";
	private final String SMART_SIZE = "728x90";
	private final String DEV_SIZE = "800x600";
	RelativeLayout banner_layout;
	RelativeLayout.LayoutParams params = new RelativeLayout.LayoutParams(RelativeLayout.LayoutParams.WRAP_CONTENT, RelativeLayout.LayoutParams.WRAP_CONTENT);


	@Override
	public int getResLayoutId() {
		return R.layout.mbridge_native_banner_activity;
	}

	@Override
	public void initData() {
		close.setChecked(true);
		updateBannerSize(mbBannerView, checkedItem);
	}

	@Override
	public void setListener() {

	}

	@Override
	public void initView() {
		mbBannerView = findViewById(R.id.mbridge_banner_view);
		banner_layout = findViewById(R.id.banner_layout);
		bidBtn = findViewById(R.id.bt_bid_banner);
		bidBtn.setVisibility(View.VISIBLE);
		refresh = findViewById(R.id.mbridge_auto_refresh);
		close = findViewById(R.id.mbridge_allow_close);
		bidBtn.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				bid();
			}
		});
		loadBtn = findViewById(R.id.bt_load_banner);
		loadBtn.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				if (!TextUtils.isEmpty(bidToken)) {
					if (mbBannerView != null){
						mbBannerView.release();
					}
					loadBanner(bidToken);
				}else{
					showToast("token is null ");
				}
			}
		});
	}

	private void bid(){
		manager = new BidManager(new BannerBidRequestParams("138791", UNIT_ID, bannerW, bannerH));
		manager.setBidListener(new BidListennning() {
			@Override
			public void onFailed(String msg) {
				Toast.makeText(getApplicationContext(),"bid failed:"+msg,Toast.LENGTH_LONG).show();
			}

			@Override
			public void onSuccessed(BidResponsed bidResponsed) {
				Toast.makeText(getApplicationContext(),"bid successed:"+bidResponsed.getPrice(),Toast.LENGTH_LONG).show();
				bidToken = bidResponsed.getBidToken();
			}
		});
		manager.bid();
	}

	private void loadBanner(String token) {
		updateBannerSize(mbBannerView, checkedItem);
		mbBannerView.init(bannerSize, "138791", UNIT_ID);
		if (refresh.isChecked())
			mbBannerView.setRefreshTime(10);
		else {
			mbBannerView.setRefreshTime(0);
		}
		mbBannerView.setAllowShowCloseBtn(close.isChecked());
		mbBannerView.setBannerAdListener(new BannerAdListener() {
			@Override
			public void onLoadFailed(MBridgeIds ids, String msg) {
				showToast("on load failed"+msg);
				Log.e(TAG, "onLoadFailed: " + msg + "  " + ids.toString());
			}

			@Override
			public void onLoadSuccessed(MBridgeIds ids) {
				showToast("on load successd");
				Log.e(TAG, "onLoadSuccessed: " + ids.toString());
			}

			@Override
			public void onClick(MBridgeIds ids) {
				showToast("onAdClick");
				Log.e(TAG, "onAdClick: " + ids.toString());
			}

			@Override
			public void onLeaveApp(MBridgeIds ids) {
				showToast("leave app");
				Log.e(TAG, "onLeaveApp: " + ids.toString());
			}

			@Override
			public void showFullScreen(MBridgeIds ids) {
				showToast("showFullScreen");
				Log.e(TAG, "showFullScreen: " + ids.toString());
			}

			@Override
			public void closeFullScreen(MBridgeIds ids) {
				showToast("closeFullScreen");
				Log.e(TAG, "closeFullScreen: " + ids.toString());
			}

			@Override
			public void onLogImpression(MBridgeIds ids) {
				showToast("onLogImpression");
				Log.e(TAG, "onLogImpression: " + ids.toString());
			}

			@Override
			public void onCloseBanner(MBridgeIds ids) {
				showToast("onCloseBanner");
				Log.e(TAG, "onCloseBanner: " + ids.toString());
			}
		});

		mbBannerView.loadFromBid(token);
	}

	private void showToast(String msg){
		Toast toast = Toast.makeText(this.getApplicationContext(), msg, Toast.LENGTH_LONG);
		toast.setText(msg);
		toast.show();
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		if(mbBannerView!= null){
			mbBannerView.release();
		}
	}

	public void showSizeChoiceDialog(View view) {
		final String[] radioItems = {MINI_SIZE, MEDIUM_SIZE, BIG_SIZE, SMART_SIZE, DEV_SIZE};
		final AlertDialog.Builder alertBuilder = new AlertDialog.Builder(this);
		alertBuilder.setTitle("SizeChoice");
		alertBuilder.setSingleChoiceItems(radioItems, checked, new DialogInterface.OnClickListener() {
			@Override
			public void onClick(DialogInterface dialogInterface, int i) {
				checked = i;
			}
		});

		alertBuilder.setPositiveButton("OK", new DialogInterface.OnClickListener() {
			@Override
			public void onClick(DialogInterface dialogInterface, int i) {
				checkedItem = checked;
				updateBannerSize(mbBannerView, checkedItem);
				banner_layout.updateViewLayout(mbBannerView,params);
				sizeChoice.dismiss();
			}
		});

		alertBuilder.setNegativeButton("Cancel", new DialogInterface.OnClickListener() {
			@Override
			public void onClick(DialogInterface dialogInterface, int i) {
				checked = checkedItem;
				sizeChoice.dismiss();
			}
		});

		sizeChoice = alertBuilder.create();
		sizeChoice.show();
	}

	public void updateBannerSize(MBBannerView mBannerView, int id){
		switch (id) {
			case 0:
				bannerSize = new BannerSize(BannerSize.STANDARD_TYPE, 0, 0);
				break;
			case 1:
				bannerSize = new BannerSize(BannerSize.MEDIUM_TYPE, 0, 0);
				break;
			case 2:
				bannerSize = new BannerSize(BannerSize.LARGE_TYPE, 0, 0);
				break;
			case 3:
				bannerSize = new BannerSize(BannerSize.SMART_TYPE, 728, 90);
				break;
			case 4:
			default:
				bannerSize = new BannerSize(BannerSize.DEV_SET_TYPE, 800, 600);
				break;
		}
		params.width = dip2px(this, bannerSize.getWidth());
		params.height = dip2px(this, bannerSize.getHeight());
		mBannerView.setLayoutParams(params);
	}

	public static int dip2px(Context context, float dpValue) {
		final float scale = context.getResources().getDisplayMetrics().density;
		return (int) (dpValue * scale + 0.5f);
	}

	public static int px2dip(Context context, float pxValue) {
		final float scale = context.getResources().getDisplayMetrics().density;
		return (int) (pxValue / scale + 0.5f);
	}
}
