package com.mbridge.sdk.demo.bid;

import android.graphics.drawable.Drawable;
import android.text.TextUtils;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import com.mbridge.msdk.MBridgeConstans;
import com.mbridge.msdk.mbbid.out.BidListennning;
import com.mbridge.msdk.mbbid.out.BidManager;
import com.mbridge.msdk.mbbid.out.BidResponsed;
import com.mbridge.msdk.out.Campaign;
import com.mbridge.msdk.out.Frame;
import com.mbridge.msdk.out.MBBidNativeHandler;
import com.mbridge.msdk.out.NativeListener.NativeAdListener;
import com.mbridge.msdk.out.NativeListener.NativeTrackingListener;
import com.mbridge.msdk.widget.MBAdChoice;
import com.mbridge.sdk.demo.BaseActivity;
import com.mbridge.sdk.demo.R;
import com.mbridge.sdk.demo.util.ImageLoadTask;

import java.util.List;
import java.util.Map;

public class BidNativeActivity extends BaseActivity implements OnClickListener {

    private static final String TAG = BidNativeActivity.class.getName();
    private Button mBtNative;
    private Button mBtBidNative;
    private Spinner mSpinner;

    public int AD_NUM = 1;
    private String mCurrentUnitId = "146868";

    private MBBidNativeHandler mNativeHandle;
    private Campaign mCampaign;
    private FrameLayout mFlAdHolder;
    private TextView mTvTitle;
    private ImageView mIvDisplayArea;

    private String token = "";

    @Override
    public int getResLayoutId() {
        return R.layout.mbridge_demo_atv_native;
    }

    @Override
    public void initView() {
        mBtBidNative = (Button) findViewById(R.id.bt_bid_native);
        ((Button) findViewById(R.id.btPreNative)).setVisibility(View.GONE);
        mBtNative = (Button) findViewById(R.id.btNative);
        mTvTitle = (TextView) findViewById(R.id.mbridge_demo_tv_title);
        mFlAdHolder = (FrameLayout) findViewById(R.id.fl_adplaceholder);
        mSpinner = (Spinner) findViewById(R.id.mbridge_demo_native_sp);
        mSpinner.setVisibility(View.GONE);
        mIvDisplayArea = (ImageView) findViewById(R.id.mbridge_demo_iv_display_area);
        mBtBidNative.setVisibility(View.VISIBLE);
    }

    @Override
    public void initData() {
        mTvTitle.setText("Bid_Native");
    }

    @Override
    public void setListener() {
        mTvTitle.setOnClickListener(this);
        mBtBidNative.setOnClickListener(this);
        mBtNative.setOnClickListener(this);
    }

    public void loadNative() {
        Map<String, Object> properties = MBBidNativeHandler.getNativeProperties("138780", mCurrentUnitId);
        properties.put(MBridgeConstans.PROPERTIES_AD_NUM, AD_NUM);
        mNativeHandle = new MBBidNativeHandler(properties, this);
        mNativeHandle.setAdListener(new NativeAdListener() {

            @Override
            public void onAdLoaded(List<Campaign> campaigns, int template) {
                Log.e(TAG, "onAdLoaded");
                if (campaigns != null && campaigns.size() > 0) {
                    mIvDisplayArea.setVisibility(View.GONE);
                    mCampaign = campaigns.get(0);
                    for (Campaign campaign : campaigns) {
                        Log.i(TAG, campaign.getAppName());
                    }
                    fillMBAdLayout();
                }
            }

            private void fillMBAdLayout() {
                final View view = LayoutInflater.from(BidNativeActivity.this)
                        .inflate(R.layout.mbridge_demo_mul_big_ad_content, null);
                final ImageView iv = (ImageView) view.findViewById(R.id.mbridge_demo_iv_image);
                if (!TextUtils.isEmpty(mCampaign.getImageUrl())) {
                    new ImageLoadTask(mCampaign.getImageUrl()) {

                        @Override
                        public void onRecived(Drawable result) {
                            iv.setImageDrawable(result);
                            mNativeHandle.registerView(view, mCampaign);
                        }
                    }.execute();
                }
                TextView tvAppName = (TextView) view.findViewById(R.id.mbridge_demo_bt_app_name);
                MBAdChoice mbAdChoice = view.findViewById(R.id.mbridge_demo_native_adchoice);
                int height = mCampaign.getAdchoiceSizeHeight();
                int width = mCampaign.getAdchoiceSizeWidth();
                ViewGroup.LayoutParams layoutParams = mbAdChoice.getLayoutParams();
                layoutParams.width = width;
                layoutParams.height = height;
                mbAdChoice.setLayoutParams(layoutParams);
                mbAdChoice.setCampaign(mCampaign);
                tvAppName.setText(mCampaign.getAppName());
                mFlAdHolder.removeAllViews();
                mFlAdHolder.addView(view);
            }

            @Override
            public void onAdLoadError(String message) {
                Log.e("", "onAdLoadError" + message);
            }

            @Override
            public void onAdClick(Campaign campaign) {
                Log.e("", "onAdClick");
            }

            @Override
            public void onAdFramesLoaded(final List<Frame> list) {

            }

            @Override
            public void onLoggingImpression(int adsourceType) {
                Log.e(TAG, "onLoggingImpression adsourceType:" + adsourceType);
            }

        });
        mNativeHandle.setTrackingListener(new NativeTrackingListener() {

            @Override
            public void onStartRedirection(Campaign campaign, String url) {
                Log.e("pro", "onStartRedirection---");
            }

            @Override
            public void onRedirectionFailed(Campaign campaign, String url) {
                Log.e("pro", "onRedirectionFailed---");
            }

            @Override
            public void onFinishRedirection(Campaign campaign, String url) {
                Log.e("pro", "onFinishRedirection---" + url);
            }

            @Override
            public void onDownloadStart(Campaign campaign) {
                Log.e("pro", "start---");
            }

            @Override
            public void onDownloadFinish(Campaign campaign) {
                Log.e("pro", "finish---");

            }

            @Override
            public void onDownloadProgress(int progress) {
                Log.e("pro", "progress----" + progress);
            }

            @Override
            public boolean onInterceptDefaultLoadingDialog() {
                return false;
            }

            @Override
            public void onShowLoading(Campaign campaign) {

            }

            @Override
            public void onDismissLoading(Campaign campaign) {

            }
        });

        mNativeHandle.bidLoad(token);

    }

    @Override
    public void onClick(View v) {
        int id = v.getId();
        switch (id) {
            case R.id.bt_bid_native:
                bidNative();
                break;
            case R.id.btNative:
                loadNative();
                break;
            case R.id.mbridge_demo_tv_title:
                finish();
                break;
        }
    }

    private void bidNative() {
        BidManager manager = new BidManager("138780", mCurrentUnitId);
        manager.setBidListener(new BidListennning() {
            @Override
            public void onFailed(String msg) {
                Toast.makeText(getApplicationContext(), "bid failed:" + msg, Toast.LENGTH_LONG).show();
            }

            @Override
            public void onSuccessed(BidResponsed bidResponsed) {
                Toast.makeText(getApplicationContext(), "bid successed:" + bidResponsed.getPrice(), Toast.LENGTH_LONG).show();
                token = bidResponsed.getBidToken();
            }
        });
        manager.bid();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mNativeHandle != null) {
            mNativeHandle.bidRelease();
        }
    }

}