package com.mbridge.sdk.demo.bid;

import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.RelativeLayout;
import android.widget.Toast;

import com.mbridge.msdk.mbbid.out.AdvancedNativeBidRequestParams;
import com.mbridge.msdk.mbbid.out.BidListennning;
import com.mbridge.msdk.mbbid.out.BidManager;
import com.mbridge.msdk.mbbid.out.BidResponsed;
import com.mbridge.msdk.out.MBNativeAdvancedHandler;
import com.mbridge.msdk.out.MBridgeIds;
import com.mbridge.msdk.out.NativeAdvancedAdListener;
import com.mbridge.sdk.demo.BaseActivity;
import com.mbridge.sdk.demo.NativeAdvancedShowActivity;
import com.mbridge.sdk.demo.R;

public class BidNativeAdvancedActivity extends BaseActivity {

	private static final String TAG = BidNativeAdvancedActivity.class.getName();
	public static final String UNIT_ID = "259532";
	public static final String PLACEMENT_ID = "202132";
	private ViewGroup mbAdView;
	private Button bidBtn,loadBtn;
	private RelativeLayout mbridgeContainerRl;
	private BidManager manager;
	private String bidToken;
	private int advancedNativeH = 640;
	private int advancedNativeW = 320;
	private MBNativeAdvancedHandler mbNativeAdvancedHandler;

	@Override
	public int getResLayoutId() {
		return R.layout.mbridge_demo_native_advanced_bid_activity;
	}

	@Override
	public void initData() {
		mbNativeAdvancedHandler = new MBNativeAdvancedHandler(this,PLACEMENT_ID,UNIT_ID);
		mbNativeAdvancedHandler.setNativeViewSize(advancedNativeH,advancedNativeW);
		mbAdView = mbNativeAdvancedHandler.getAdViewGroup();
	}

	@Override
	public void setListener() {
		if (mbNativeAdvancedHandler != null) {
			mbNativeAdvancedHandler.setAdListener(new NativeAdvancedAdListener() {
				@Override
				public void onLoadSuccessed(MBridgeIds ids) {
					Log.e(TAG, "onLoadSuccessed: " + ids.toString());
					Toast.makeText(BidNativeAdvancedActivity.this,"onLoadSuccessed:",Toast.LENGTH_LONG).show();
				}

				@Override
				public void onLoadFailed(MBridgeIds ids, String msg) {
					Log.e(TAG, "onLoadFailed: " + msg + "  " + ids.toString());
					Toast.makeText(BidNativeAdvancedActivity.this,"onLoadFailed:" ,Toast.LENGTH_LONG).show();
				}

				@Override
				public void onLogImpression(MBridgeIds ids) {
					Log.e(TAG, "onLogImpression: " + ids.toString() );
					Toast.makeText(BidNativeAdvancedActivity.this,"onLogImpression:" ,Toast.LENGTH_LONG).show();
				}

				@Override
				public void onClick(MBridgeIds ids) {
					Log.e(TAG, "onClick: " + ids.toString() );
					Toast.makeText(BidNativeAdvancedActivity.this,"onClick:" ,Toast.LENGTH_LONG).show();
				}

				@Override
				public void onLeaveApp(MBridgeIds ids) {
					Log.e(TAG, "onLeaveApp: " + ids.toString() );
					Toast.makeText(BidNativeAdvancedActivity.this,"onLeaveApp:" ,Toast.LENGTH_LONG).show();
				}

				@Override
				public void showFullScreen(MBridgeIds ids) {
					Log.e(TAG, "showFullScreen: " + ids.toString() );
					Toast.makeText(BidNativeAdvancedActivity.this,"showFullScreen:" ,Toast.LENGTH_LONG).show();
				}

				@Override
				public void closeFullScreen(MBridgeIds ids) {
					Log.e(TAG, "closeFullScreen: " + ids.toString() );
					Toast.makeText(BidNativeAdvancedActivity.this,"closeFullScreen:" ,Toast.LENGTH_LONG).show();
				}

				@Override
				public void onClose(MBridgeIds ids) {
					Log.e(TAG, "onDismiss: " + ids.toString() );
					Toast.makeText(BidNativeAdvancedActivity.this,"onDismiss:" ,Toast.LENGTH_LONG).show();
				}
			});
		}
	}

	@Override
	public void initView() {
		mbridgeContainerRl = findViewById(R.id.mbridge_container_rl);
		bidBtn = findViewById(R.id.bt_bid_advancedNative);
		bidBtn.setVisibility(View.VISIBLE);
		bidBtn.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				bid();
			}
		});
		loadBtn = findViewById(R.id.bt_load_advancedNative);
		findViewById(R.id.bt_show_advanced).setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				ViewGroup nativeAdvanceViewGroup = mbNativeAdvancedHandler.getAdViewGroup();
				ViewGroup nativeAdvanceParent = (ViewGroup) nativeAdvanceViewGroup.getParent();
				if (nativeAdvanceParent != null) {
					nativeAdvanceParent.removeView(nativeAdvanceViewGroup);
				}
				mbridgeContainerRl.addView(nativeAdvanceViewGroup);
			}
		});
		loadBtn.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				if (!TextUtils.isEmpty(bidToken)) {
					load(bidToken);
				}else{
					showToast("token is null ");
				}
			}
		});
	}

	private void bid(){
		manager = new BidManager(new AdvancedNativeBidRequestParams(PLACEMENT_ID, UNIT_ID, advancedNativeW, advancedNativeH));
		manager.setBidListener(new BidListennning() {
			@Override
			public void onFailed(String msg) {
				Toast.makeText(getApplicationContext(),"bid failed:"+msg,Toast.LENGTH_SHORT).show();
			}

			@Override
			public void onSuccessed(BidResponsed bidResponsed) {
				Toast.makeText(getApplicationContext(),"bid successed:"+bidResponsed.getPrice(),Toast.LENGTH_SHORT).show();
				bidToken = bidResponsed.getBidToken();
			}
		});
		manager.bid();
	}

	private void load(String token) {
		if(mbNativeAdvancedHandler != null){
			mbNativeAdvancedHandler.loadByToken(token);
		}


	}


	@Override
	protected void onResume() {
		super.onResume();
		mbNativeAdvancedHandler.onResume();
	}

	@Override
	protected void onPause() {
		super.onPause();
		mbNativeAdvancedHandler.onPause();
	}

	private void showToast(String msg){
		Toast.makeText(this,msg,Toast.LENGTH_LONG).show();
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		if(mbNativeAdvancedHandler != null){
			mbNativeAdvancedHandler.release();
		}
	}
}
