package com.mbridge.sdk.demo.bid;

import android.app.Dialog;
import android.content.IntentFilter;
import android.net.ConnectivityManager;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.mbridge.msdk.MBridgeConstans;
import com.mbridge.msdk.mbbid.out.BidListennning;
import com.mbridge.msdk.mbbid.out.BidManager;
import com.mbridge.msdk.mbbid.out.BidResponsed;
import com.mbridge.msdk.newinterstitial.out.MBBidNewInterstitialHandler;
import com.mbridge.msdk.newinterstitial.out.NewInterstitialListener;
import com.mbridge.msdk.out.MBridgeIds;
import com.mbridge.msdk.out.RewardInfo;
import com.mbridge.msdk.videocommon.download.NetStateOnReceive;
import com.mbridge.sdk.demo.BaseActivity;
import com.mbridge.sdk.demo.R;
import com.mbridge.sdk.demo.view.CommonTitleLayout;

public class BidNewInterstitialActivity extends BaseActivity implements OnClickListener {
	private final static String TAG = "BidNIActivity";
	private Button bt_bid;
	private Button bt_load;
	private Button bt_show;
	private Button bt_mute;
	private Button bt_unmute;
	private CommonTitleLayout mTitleLayout;
	private MBBidNewInterstitialHandler mMBNewInterstitalHandler;
	private ProgressBar mProgressBar;
	private NetStateOnReceive mNetStateOnReceive;
	private Dialog mDialog;
	private String mRewardUnitId = "1717411";
	private String placementId = "403703";
	private String bidToken = "";
	private BidManager manager;

	@Override
	public int getResLayoutId() {
		return R.layout.mbridge_demo_atv_reward;
	}

	@Override
	public void initView() {
		bt_bid = (Button) findViewById(R.id.bt_bid);
		bt_bid.setVisibility(View.VISIBLE);
		bt_load = (Button) findViewById(R.id.bt_load);
		bt_show = (Button) findViewById(R.id.bt_show);
		bt_mute = (Button) findViewById(R.id.bt_mute);
		bt_unmute = (Button) findViewById(R.id.bt_unmute);
		mProgressBar = (ProgressBar) findViewById(R.id.mbridge_demo_progress);
		mTitleLayout = (CommonTitleLayout) findViewById(R.id.mbridge_demo_common_title_layout);
	}

	@Override
	public void initData() {
		initHandler();

	}

	@Override
	public void setListener() {
		mTitleLayout.setTitleText("Head Bid New Interstitial");
		bt_bid.setOnClickListener(this);
		bt_load.setOnClickListener(this);
		bt_show.setOnClickListener(this);
		bt_mute.setOnClickListener(this);
		bt_unmute.setOnClickListener(this);
	}

	private void showLoadding() {
		mProgressBar.setVisibility(View.VISIBLE);
	}

	private void hideLoadding() {
		mProgressBar.setVisibility(View.GONE);
	}

	private void initHandler() {
		try {
			// Declare network status for downloading video
			if (mNetStateOnReceive == null) {
				mNetStateOnReceive = new NetStateOnReceive();
				IntentFilter filter = new IntentFilter();
				filter.addAction(ConnectivityManager.CONNECTIVITY_ACTION);
				registerReceiver(mNetStateOnReceive, filter);
			}

			//mMBInterstitalVideoHandler = new MBBidInterstitialVideoHandler(this, mRewardUnitId);
			mMBNewInterstitalHandler = new MBBidNewInterstitialHandler(this, placementId, mRewardUnitId);
			mMBNewInterstitalHandler.setInterstitialVideoListener(new NewInterstitialListener() {

				@Override
				public void onLoadCampaignSuccess(MBridgeIds ids) {
					Log.e(TAG, "onLoadCampaignSuccess: " + Thread.currentThread() + " " + ids.toString());
					Toast.makeText(getApplicationContext(), "onLoadCampaignSuccess()", Toast.LENGTH_LONG).show();
				}

				@Override
				public void onResourceLoadSuccess(MBridgeIds ids) {
					Log.e(TAG, "onResourceLoadSuccess: " + Thread.currentThread() + " " + ids.toString());
					hideLoadding();
					Toast.makeText(getApplicationContext(), "onResourceLoadSuccess()", Toast.LENGTH_LONG).show();
				}

				@Override
				public void onResourceLoadFail(MBridgeIds ids, String errorMsg) {
					Log.e(TAG, "onResourceLoadFail errorMsg: " + errorMsg + " " + ids.toString());
					hideLoadding();
					Toast.makeText(getApplicationContext(), errorMsg, Toast.LENGTH_LONG).show();
				}

				@Override
				public void onShowFail(MBridgeIds ids, String errorMsg) {
					Log.e(TAG, "onShowFail: " + errorMsg + " " + ids.toString());
					Toast.makeText(getApplicationContext(), "errorMsg:" + errorMsg, Toast.LENGTH_LONG).show();
				}

				@Override
				public void onAdShow(MBridgeIds ids) {
					Log.e(TAG, "onAdShow: "+ ids.toString());
					Toast.makeText(getApplicationContext(), "onAdShow", Toast.LENGTH_LONG).show();
				}

				@Override
				public void onAdClose(MBridgeIds ids, RewardInfo info) {
					Log.e(TAG, "onAdClose: " +  "isCompleteView：" + info.isCompleteView() + " " + ids.toString());
					Toast.makeText(getApplicationContext(),"onADClose:"+info.isCompleteView(),Toast.LENGTH_LONG).show();
				}

				@Override
				public void onAdClicked(MBridgeIds ids) {
					Log.e(TAG, "onAdClicked: " + ids.toString());
					Toast.makeText(getApplicationContext(), "onAdClicked", Toast.LENGTH_LONG).show();
				}

				@Override
				public void onVideoComplete(MBridgeIds ids) {
					Log.e(TAG,"onVideoComplete: " + ids.toString());
					Toast.makeText(getApplicationContext(),"onVideoComplete",Toast.LENGTH_LONG).show();
				}

				/**
				 * If you called {@link com.mbridge.msdk.newinterstitial.out.MBNewInterstitialHandler#setIVRewardEnable(int, int)}
				 * will callback this method.
				 * You can decide whether to give users a reward based on the return value.
				 *
				 * In RewardInfo :
				 *  isCompleteView : complete status.
				 *                   This parameter indicates whether the video or playable has finished playing.
				 *
				 *  rewardAlertStatus : interstitialVideo reward  alert  window status.
				 *                          This parameter is used to indicate the status of the alert dialog.
				 *                          If the dialog is not shown, it will return {@link MBridgeConstans#IVREWARDALERT_STATUS_NOTSHOWN}
				 *                          If the user clicks the dialog's continue button, it will return {@link MBridgeConstans#IVREWARDALERT_STATUS_CLICKCONTINUE}
				 *                          If the user clicks the dialog's cancel button, it will return {@link MBridgeConstans#IVREWARDALERT_STATUS_CLICKCANCEL}
				 *
				 */
				@Override
				public void onAdCloseWithNIReward(MBridgeIds ids, RewardInfo info) {
					Log.e(TAG, "onAdCloseWithNIReward: " + ids.toString() + "  " + info.toString());
					Toast.makeText(getApplicationContext(),"onAdCloseWithNIReward",Toast.LENGTH_LONG).show();

					Log.e(TAG, info.isCompleteView() ? "Video playback/playable is complete." : "Video playback/playable is not complete.");

					int rewardAlertStatus = info.getRewardAlertStatus();

					if (rewardAlertStatus == MBridgeConstans.IVREWARDALERT_STATUS_NOTSHOWN) {
						Log.e(TAG,"The dialog is not show.");
					}

					if (rewardAlertStatus == MBridgeConstans.IVREWARDALERT_STATUS_CLICKCONTINUE) {
						Log.e(TAG,"The dialog's continue button clicked.");
					}

					if (rewardAlertStatus == MBridgeConstans.IVREWARDALERT_STATUS_CLICKCANCEL) {
						Log.e(TAG,"The dialog's cancel button clicked.");
					}
				}

				@Override
				public void onEndcardShow(MBridgeIds ids) {
					Log.e(TAG,"onEndcardShow: " + ids.toString());
					Toast.makeText(getApplicationContext(),"onEndcardShow",Toast.LENGTH_LONG).show();
				}
			});

			manager = new BidManager(placementId, mRewardUnitId);
			manager.setBidListener(new BidListennning() {
				@Override
				public void onFailed(String msg) {
					Toast.makeText(getApplicationContext(),"bid failed:"+msg,Toast.LENGTH_LONG).show();
				}

				@Override
				public void onSuccessed(BidResponsed bidResponsed) {
					Toast.makeText(getApplicationContext(),"bid successed:"+bidResponsed.getPrice(),Toast.LENGTH_LONG).show();
					bidToken = bidResponsed.getBidToken();
				}
			});
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	@Override
	public void onClick(View v) {
		switch (v.getId()) {
			case R.id.bt_bid:
				if (manager != null) {
					manager.bid();
				}
				break;
			case R.id.bt_load:
				showLoadding();
				if (mMBNewInterstitalHandler != null) {
					/**
					 * @see com.mbridge.sdk.demo.InterstitialVideoActivity#onClick(View)
					 */
					mMBNewInterstitalHandler.setIVRewardEnable(MBridgeConstans.IVREWARD_TYPE_CLOSEMODE, 10);
					mMBNewInterstitalHandler.loadFromBid(bidToken);
				}
				break;
			case R.id.bt_show:
				if (mMBNewInterstitalHandler != null && mMBNewInterstitalHandler.isBidReady()) {
					mMBNewInterstitalHandler.showFromBid();
				}
				break;
			case R.id.bt_mute:
				if (mMBNewInterstitalHandler != null) {
					Toast.makeText(getApplicationContext(),"bt_mute",Toast.LENGTH_LONG).show();
					mMBNewInterstitalHandler.playVideoMute(MBridgeConstans.REWARD_VIDEO_PLAY_MUTE);
				}
				break;
			case R.id.bt_unmute:
				if (mMBNewInterstitalHandler != null) {
					Toast.makeText(getApplicationContext(),"bt_unmute",Toast.LENGTH_LONG).show();
					mMBNewInterstitalHandler.playVideoMute(MBridgeConstans.REWARD_VIDEO_PLAY_NOT_MUTE);
				}
				break;
		}
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		try {
			if (mDialog != null) {
				mDialog = null;
			}
			if (mNetStateOnReceive != null) {
				unregisterReceiver(mNetStateOnReceive);
			}
			if(mMBNewInterstitalHandler != null){
				mMBNewInterstitalHandler.setInterstitialVideoListener(null);
			}
			if(manager != null){
				manager.setBidListener(null);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public void showDialog(String RewardName, float RewardAmout) {
		try {
			mDialog = new Dialog(BidNewInterstitialActivity.this);
			View view = View.inflate(BidNewInterstitialActivity.this, R.layout.dialog_reward, null);
			TextView tvRewardName = (TextView) view.findViewById(R.id.tv_rewardName);
			TextView tvRewardAmout = (TextView) view.findViewById(R.id.tv_RewardAmout);
			tvRewardName.setText(RewardName + "");
			tvRewardAmout.setText(RewardAmout + "");
			mDialog.setContentView(view);
			mDialog.show();
		}catch (Throwable t){
			t.printStackTrace();
		}
	}





}
