package com.mbridge.sdk.demo.bid;

import android.app.Dialog;
import android.content.IntentFilter;
import android.net.ConnectivityManager;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.mbridge.msdk.MBridgeConstans;
import com.mbridge.msdk.mbbid.out.BidListennning;
import com.mbridge.msdk.mbbid.out.BidManager;
import com.mbridge.msdk.mbbid.out.BidResponsed;
import com.mbridge.msdk.out.MBBidRewardVideoHandler;
import com.mbridge.msdk.out.MBridgeIds;
import com.mbridge.msdk.out.RewardInfo;
import com.mbridge.msdk.out.RewardVideoListener;
import com.mbridge.msdk.videocommon.download.NetStateOnReceive;
import com.mbridge.sdk.demo.BaseActivity;
import com.mbridge.sdk.demo.R;
import com.mbridge.sdk.demo.view.CommonTitleLayout;

public class BidRewardActivity extends BaseActivity implements OnClickListener {
	private final static String TAG = "BidRewardActivity";
	private Button bt_bid;
	private Button bt_load;
	private Button bt_show;
	private Button bt_mute;
	private Button bt_unmute;
	private CommonTitleLayout mTitleLayout;
	private MBBidRewardVideoHandler mMBRewardVideoHandler;
	private ProgressBar mProgressBar;
	private NetStateOnReceive mNetStateOnReceive;
	private Dialog mDialog;
	private String mRewardUnitId = "146874";
	private String mRewardId = "12817";
	private String mUserId = "123";
	private String bidToken = "";
	private BidManager manager;

	@Override
	public int getResLayoutId() {
		return R.layout.mbridge_demo_atv_reward;
	}

	@Override
	public void initView() {
		bt_bid = (Button) findViewById(R.id.bt_bid);
		bt_bid.setVisibility(View.VISIBLE);
		bt_load = (Button) findViewById(R.id.bt_load);
		bt_show = (Button) findViewById(R.id.bt_show);
		bt_mute = (Button) findViewById(R.id.bt_mute);
		bt_unmute = (Button) findViewById(R.id.bt_unmute);
		mProgressBar = (ProgressBar) findViewById(R.id.mbridge_demo_progress);
		mTitleLayout = (CommonTitleLayout) findViewById(R.id.mbridge_demo_common_title_layout);
	}

	@Override
	public void initData() {
		initHandler();

	}

	@Override
	public void setListener() {
		mTitleLayout.setTitleText("Head Bid RewardVideo");
		bt_bid.setOnClickListener(this);
		bt_load.setOnClickListener(this);
		bt_show.setOnClickListener(this);
		bt_mute.setOnClickListener(this);
		bt_unmute.setOnClickListener(this);
	}

	private void showLoadding() {
		mProgressBar.setVisibility(View.VISIBLE);
	}

	private void hideLoadding() {
		mProgressBar.setVisibility(View.GONE);
	}

	private void initHandler() {
		try {
			if (mNetStateOnReceive == null) {
				mNetStateOnReceive = new NetStateOnReceive();
				IntentFilter filter = new IntentFilter();
				filter.addAction(ConnectivityManager.CONNECTIVITY_ACTION);
				registerReceiver(mNetStateOnReceive, filter);
			}

			mMBRewardVideoHandler = new MBBidRewardVideoHandler(this, "138786", mRewardUnitId);
			mMBRewardVideoHandler.setRewardVideoListener(new RewardVideoListener() {

				@Override
				public void onLoadSuccess(MBridgeIds ids) {
					Log.e(TAG, "onLoadSuccess: " + (TextUtils.isEmpty(ids.getPlacementId()) ? "" : ids.getPlacementId()) + "  " + ids.getUnitId());
					Toast.makeText(getApplicationContext(), "onLoadSuccess()", Toast.LENGTH_LONG).show();

				}

				@Override
				public void onVideoLoadSuccess(MBridgeIds ids) {
					Log.e(TAG, "onVideoLoadSuccess: " + (TextUtils.isEmpty(ids.getPlacementId()) ? "" : ids.getPlacementId()) + "  " + ids.getUnitId());
					hideLoadding();
					Toast.makeText(getApplicationContext(), "onVideoLoadSuccess()", Toast.LENGTH_LONG).show();

				}

				@Override
				public void onVideoLoadFail(MBridgeIds ids, String errorMsg) {
					Log.e(TAG, "onVideoLoadFail: " + errorMsg + "  " + ids.toString());
					hideLoadding();
					Toast.makeText(getApplicationContext(), errorMsg, Toast.LENGTH_LONG).show();
				}

				@Override
				public void onShowFail(MBridgeIds ids, String errorMsg) {
					Log.e(TAG, "onShowFail: " + errorMsg + "  " + ids.toString());
					Toast.makeText(getApplicationContext(), "errorMsg:" + errorMsg, Toast.LENGTH_LONG).show();
				}

				@Override
				public void onAdShow(MBridgeIds ids) {
					Log.e(TAG, "onAdShow: " + ids.toString());
					Toast.makeText(getApplicationContext(), "onAdShow", Toast.LENGTH_LONG).show();
				}

				@Override
				public void onAdClose(MBridgeIds ids, RewardInfo rewardInfo) {
					Log.e(TAG, "onAdClose : " + ids.toString() + "  " + rewardInfo.toString());
					Toast.makeText(getApplicationContext(), "onADClose:" + rewardInfo.toString(), Toast.LENGTH_LONG).show();
				}

				@Override
				public void onVideoAdClicked(MBridgeIds ids) {
					Log.e(TAG, "onVideoAdClicked : " + (TextUtils.isEmpty(ids.getPlacementId()) ? "" : ids.getPlacementId()) + "  " + ids.getUnitId());
					Toast.makeText(getApplicationContext(), "onVideoAdClicked", Toast.LENGTH_LONG).show();
				}

				@Override
				public void onVideoComplete(MBridgeIds ids) {
					Log.e(TAG, "onVideoComplete : " + (TextUtils.isEmpty(ids.getPlacementId()) ? "" : ids.getPlacementId()) + "  " + ids.getUnitId());
					Toast.makeText(getApplicationContext(), "onVideoComplete", Toast.LENGTH_LONG).show();
				}

				@Override
				public void onEndcardShow(MBridgeIds ids) {
					Log.e(TAG, "onEndcardShow : " + (TextUtils.isEmpty(ids.getPlacementId()) ? "" : ids.getPlacementId()) + "  " + ids.getUnitId());
					Toast.makeText(getApplicationContext(), "onEndcardShow", Toast.LENGTH_LONG).show();
				}

			});
			manager = new BidManager("138786", mRewardUnitId, "0");
			manager.setBidListener(new BidListennning() {
				@Override
				public void onFailed(String msg) {
					Toast.makeText(getApplicationContext(),"bid failed:"+msg,Toast.LENGTH_LONG).show();
				}

				@Override
				public void onSuccessed(BidResponsed bidResponsed) {
					Toast.makeText(getApplicationContext(),"bid successed:"+bidResponsed.getPrice(),Toast.LENGTH_LONG).show();
					bidToken = bidResponsed.getBidToken();
				}
			});
			manager.setRewardPlus(true);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	@Override
	public void onClick(View v) {
		switch (v.getId()) {
			case R.id.bt_bid:
				if (manager != null) {
					manager.bid();
				}
				break;
			case R.id.bt_load:
				showLoadding();
				mMBRewardVideoHandler.loadFromBid(bidToken);
				break;
			case R.id.bt_show:
				if (mMBRewardVideoHandler.isBidReady()) {
					mMBRewardVideoHandler.showFromBid(mRewardId, mUserId);
				}
				break;
			case R.id.bt_mute:
				if (mMBRewardVideoHandler != null) {
					Toast.makeText(getApplicationContext(),"bt_mute",Toast.LENGTH_LONG).show();
					mMBRewardVideoHandler.playVideoMute(MBridgeConstans.REWARD_VIDEO_PLAY_MUTE);
				}
				break;
			case R.id.bt_unmute:
				if (mMBRewardVideoHandler != null) {
					Toast.makeText(getApplicationContext(),"bt_unmute",Toast.LENGTH_LONG).show();
					mMBRewardVideoHandler.playVideoMute(MBridgeConstans.REWARD_VIDEO_PLAY_NOT_MUTE);
				}
				break;
		}
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		try {
			if (mDialog != null) {
				mDialog = null;
			}
			if (mNetStateOnReceive != null) {
				unregisterReceiver(mNetStateOnReceive);
			}
			if(mMBRewardVideoHandler != null){
				mMBRewardVideoHandler.setRewardVideoListener(null);
			}
			if(manager != null){
				manager.setBidListener(null);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public void showDialog(String RewardName, float RewardAmout) {
		try {
			mDialog = new Dialog(BidRewardActivity.this);
			View view = View.inflate(BidRewardActivity.this, R.layout.dialog_reward, null);
			TextView tvRewardName = (TextView) view.findViewById(R.id.tv_rewardName);
			TextView tvRewardAmout = (TextView) view.findViewById(R.id.tv_RewardAmout);
			tvRewardName.setText(RewardName + "");
			tvRewardAmout.setText(RewardAmout + "");
			mDialog.setContentView(view);
			mDialog.show();
		}catch (Throwable t){
			t.printStackTrace();
		}
	}





}
