package com.mbridge.sdk.demo.util;

import android.app.Activity;
import android.content.Intent;
import android.os.Build;
import android.text.TextUtils;
import android.util.Log;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.RelativeLayout;

import androidx.annotation.RequiresApi;

import com.mbridge.msdk.mbbid.out.BidListennning;
import com.mbridge.msdk.mbbid.out.BidManager;
import com.mbridge.msdk.mbbid.out.BidResponsed;
import com.mbridge.msdk.mbbid.out.SplashBidRequestParams;
import com.mbridge.msdk.out.MBSplashHandler;
import com.mbridge.msdk.out.MBSplashLoadListener;
import com.mbridge.msdk.out.MBSplashShowListener;
import com.mbridge.msdk.out.MBridgeIds;
import com.mbridge.msdk.out.MBridgeSDKFactory;
import com.mbridge.msdk.out.ZoomOutTypeEnum;
import com.mbridge.sdk.demo.R;
import com.mbridge.sdk.demo.SplashActivity;
import com.mbridge.sdk.demo.SplashShowActivity;

import java.lang.ref.WeakReference;

public class SplashHelper {
    private String TAG = "SplashHelper";
    MBSplashHandler mbSplashHandler;
    private ViewGroup container;
    private int countDownTime = 10;
    private int loadTimeOut = 30;
    private String unitId= "209547";
    private int TYPE_SHOW = 1;
    private int TYPE_LOAD_AND_SHOW = 2;
    private Activity showAc;
    private boolean isSupportZoomOut;
    private BidManager bidManager;
    private String token;
    private String placement;
    public static String PARAMS_TYPE= "type";
    public static String PARAMS_UNIT_ID = "unitId";
    public static String PARAMS_COUNT_DOWN_TIME ="countDownTime";
    public static String PARAMS_LOAD_TIME_OUT = "loadTimeOut";
    public static String PARAMS_TOKEN = "token";

    private static final class Holder{
        private static SplashHelper mInstance = new SplashHelper();
    }
    public static SplashHelper getInstance() {
        return SplashHelper.Holder.mInstance;
    }
    private SplashHelper(){}

    public void init(Activity activity,String placementId,String unitId){
        this.unitId = unitId;
        this.placement = placementId;
        init(activity);
    }

    public void init(Activity activity){
        try {
            mbSplashHandler = new MBSplashHandler(placement, unitId);
            mbSplashHandler.setLoadTimeOut(loadTimeOut);
            ImageView logo = new ImageView(activity);
            logo.setScaleType(ImageView.ScaleType.FIT_CENTER);
            logo.setImageResource(R.drawable.mbridge_logo_green);
            RelativeLayout.LayoutParams params = new RelativeLayout.LayoutParams(320,
                    150);
            params.addRule(RelativeLayout.CENTER_IN_PARENT,RelativeLayout.TRUE);

            RelativeLayout relativeLayout = new RelativeLayout(activity);
            relativeLayout.addView(logo,params);
            RelativeLayout.LayoutParams relativeParams = new RelativeLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT,
                    ViewGroup.LayoutParams.MATCH_PARENT);
            relativeLayout.setLayoutParams(relativeParams);
            mbSplashHandler.setLogoView(relativeLayout, 400, 250);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void initBidManager(String placementId,String unitId){
        this.unitId = unitId;
        this.placement = placementId;
        bidManager = new BidManager(new SplashBidRequestParams(placementId, unitId, true,2,30,30));
    }

    public void setListener() {
        if (bidManager != null) {
            bidManager.setBidListener(new BidListennning() {
                @Override
                public void onFailed(String msg) {
                    Log.e(TAG, "onFailed:  " + msg);
                }

                @Override
                public void onSuccessed(BidResponsed bidResponsed) {
                    token = bidResponsed.getBidToken();
                    Log.e(TAG, "onSuccessed: token " + token);
                }
            });
        }
        mbSplashHandler.setSplashLoadListener(new MBSplashLoadListener() {
            @Override
            public void onLoadSuccessed(MBridgeIds ids, int reqType) {
                Log.e(TAG, "onLoadSuccessed: " + reqType + " " + ids.toString());

            }

            @Override
            public void onLoadFailed(MBridgeIds ids, String msg, int reqType) {
                Log.e(TAG, "onLoadFailed: " + msg + "  " + reqType + " " + ids.toString());
            }

            @Override
            public void isSupportZoomOut(MBridgeIds ids,boolean support) {
                isSupportZoomOut = support;
                Log.e(TAG, "isSupportZoomOut: " + support +  " ids" + ids.toString());
            }
        });
        mbSplashHandler.setSplashShowListener(new MBSplashShowListener() {
            @Override
            public void onShowSuccessed(MBridgeIds ids) {
                Log.e(TAG, "onShowSuccessed: " + ids.toString());
            }

            @Override
            public void onShowFailed(MBridgeIds ids, String msg) {
                Log.e(TAG, "onShowFailed: " + msg + " " + ids.toString());
            }

            @Override
            public void onAdClicked(MBridgeIds ids) {
                Log.e(TAG, "onAdClicked: " + ids.toString());
            }

            @Override
            public void onDismiss(MBridgeIds ids, int type) {
                Log.e(TAG, "onDismiss: " + type + " " + ids.toString());
                if(showAc != null){
                    if (isSupportZoomOut) {
                        showAc.setResult(Activity.RESULT_OK);
                    }
                    showAc.finish();
                }
                if(type == 6 ||type == 4 ||type == 5 ){
                    MBZoomOutManager.getInstance().dismissZoomView();

                }
            }

            @Override
            public void onAdTick(MBridgeIds ids, long millisUntilFinished) {
                Log.e(TAG, "onAdTick: " + millisUntilFinished + " " + ids.toString());
            }

            @Override
            public void onZoomOutPlayStart(MBridgeIds ids) {
                Log.e(TAG, "onZoomOutPlayStart: " + ids.toString());
            }

            @Override
            public void onZoomOutPlayFinish(MBridgeIds ids) {
                Log.e(TAG, "onZoomOutPlayFinish: " + ids.toString());
            }
        });
    }

    public void preload(){
        mbSplashHandler.preLoad();
    }
    public void preloadBid(){
        mbSplashHandler.preLoadByToken(token);
    }
    public void show(Activity activity){
        if(mbSplashHandler.isReady()){
            startIntent(activity,1);
        }
    }
    public void showBid(Activity activity){
        if(mbSplashHandler.isReady(token)){
            startIntent(activity,1);
        }
    }
    public void loadAndShow(Activity activity){
        startIntent(activity,2);
    }

    public void loadAndShowBid(Activity activity){
       startIntent(activity,2);
    }
    private void startIntent(Activity activity,int type){
        Intent intent = new Intent(activity,SplashShowActivity.class);
        intent.putExtra(PARAMS_TYPE,type);
        intent.putExtra(PARAMS_UNIT_ID,unitId);
        intent.putExtra(PARAMS_COUNT_DOWN_TIME,countDownTime);
        intent.putExtra(PARAMS_LOAD_TIME_OUT,loadTimeOut);
        if (!TextUtils.isEmpty(token)) {
            intent.putExtra(PARAMS_TOKEN,token);
        }
        activity.startActivityForResult(intent,SplashActivity.ZOOM_OUT_REQUEST_CODE);
    }

    @RequiresApi(api = Build.VERSION_CODES.KITKAT)
    public void showZoomOut(Activity activity, ViewGroup zoomOutViewLayout){
        if(activity == null || zoomOutViewLayout == null){
            return;
        }
        zoomOutViewLayout.removeAllViews();
        MBridgeSDKFactory.getMBridgeSDK().updateDialogWeakActivity(new WeakReference<Activity>(activity));
        MBZoomOutManager.getInstance().startZoomOut((ViewGroup) activity.getWindow().getDecorView(),
                zoomOutViewLayout,
                new MBZoomOutManager.AnimationCallBack() {
                    @Override
                    public void animationStart(int animationTime) {

                    }

                    @Override
                    public void animationEnd() {
                        if(mbSplashHandler != null){
                            mbSplashHandler.zoomOutAttacked();
                        }
                    }
                }, ZoomOutTypeEnum.FloatBall);
    }

    public void onResume() {
        if(mbSplashHandler != null){
            mbSplashHandler.onResume();
        }
    }


    public void onPause() {
        if(mbSplashHandler != null){
            mbSplashHandler.onPause();
        }
    }
    public void onDestroy() {
        MBZoomOutManager.getInstance().clearStaticData();
    }
    public void bid(){
        if (bidManager != null) {
            bidManager.bid();
        }
    }

    public void updateSplashView(Activity ac,ViewGroup container){
        MBZoomOutManager.getInstance().setSplashInfo(mbSplashHandler,container,ac.getWindow().getDecorView());
    }

    public void show(Activity ac,int type,String token,ViewGroup container){
        updateSplashView(ac,container);
        this.container = container;
        showAc = ac;
        MBridgeSDKFactory.getMBridgeSDK().updateDialogWeakActivity(new WeakReference<Activity>(showAc));
        if(TextUtils.isEmpty(token)){
            if(type == TYPE_SHOW){
                mbSplashHandler.show(container);
            }else if(type == TYPE_LOAD_AND_SHOW){
                mbSplashHandler.loadAndShow(container);
            }else {
                Log.e(TAG, "the type is unknow");
            }
        }else {
            if(type == TYPE_SHOW){
                mbSplashHandler.show(container,token);
            }else if(type == TYPE_LOAD_AND_SHOW){
                mbSplashHandler.loadAndShowByToken(token,container);
            }else {
                Log.e(TAG, "the type is unknow");

            }
        }
    }
}
