package com.squareup.leakcanary;

import android.os.Environment;
import android.util.Log;

import com.mbridge.msdk.out.MBConfiguration;
import com.mbridge.sdk.demo.httpRequest.HttpRequests;
import com.squareup.haha.guava.collect.Maps;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Objects;


public class LeakNotifyService extends DisplayLeakServiceNoNotification {
    private final String TAG = getClass().getSimpleName();
    public static JSONObject leakDetails;
    public String sdkVer = MBConfiguration.SDK_VERSION;


    @Override
    protected void afterDefaultHandling(HeapDump heapDump, AnalysisResult result, String leakInfo) {
        if (!result.leakFound || result.excludedLeak) {
            return;
        }
        Log.e("LeakUploadService", "Memory leak detected: \n" + result.leakTrace);
        String className = result.className;
        String pkgName = leakInfo.trim().split(":")[0].split(" ")[1];
        String pkgVer = leakInfo.trim().split(":")[1];
        String leakDetail = leakInfo.split("\n\n")[0] + "\n\n" + leakInfo.split("\n\n")[1];
        try {

            JSONObject uploadInfo = new JSONObject();
            uploadInfo.put("className", className);
            uploadInfo.put("pkgName", pkgName);
            uploadInfo.put("pkgVer", pkgVer);
            uploadInfo.put("sdkVer", sdkVer);
            uploadInfo.put("leakDetail", leakDetail);
            leakDetails = uploadInfo;
            uploadData(leakDetails);
            sentDing(leakDetail);
        } catch (Exception e) {
            Log.e("LeakUploadService", Objects.requireNonNull(e.getMessage()));
        }

    }

    public void uploadData(JSONObject leakinfo) throws JSONException {
        String filePath = Environment.getExternalStorageDirectory()
                + "/files/leakcanary/*.result";
        String HOST_NAME = "http://192.168.6.148";
        String PORT = "10086";
        String PATH = "/UploadServer/upload";
        final String targetUrl = HOST_NAME + ":" + PORT + PATH;


        HashMap<String, Object> params = Maps.newHashMap();
        params.put("leakInfo", leakinfo);
        HttpRequests.getInstance().postJson(targetUrl, leakinfo.toString(), new HttpRequests.OnRequestCallback() {
            @Override
            public void onSuccess(String result) {
                Log.d(TAG, "onSuccess: " + result);
            }

            @Override
            public void onFail(String failMessage) {
                Log.d(TAG, "onFail: " + failMessage);
            }

            @Override
            public void onError(String errorMessage) {
                Log.d(TAG, "onError: " + errorMessage);
            }
        });

    }

    public void sentDing(String message) {
        try {
            String dingRobotUrl = "https://oapi.dingtalk.com/robot/send?access_token=27afb1d7e4eacc8a3546681fc3aa608a522b1aa4d34040b8459624a026a1c927";
            String dingMessage = "";
            JSONObject contentInfo = new JSONObject();
            dingMessage = "泄露通知:\n" + "sdk_version:" + sdkVer+ "\n" +  message;
            contentInfo.put("content", dingMessage);

            JSONObject atInfo = new JSONObject();
            List<String> atMobiles = Collections.singletonList("");
            atInfo.put("isAtAll", false);
            atInfo.put("atMobiles", atMobiles);
            JSONObject paramsPost = new JSONObject();
            paramsPost.put("msgtype", "text");
            paramsPost.put("text", contentInfo);
            paramsPost.put("at", atInfo);

            String body = "";
            body = paramsPost.toString();

            HttpRequests.getInstance().postJson(dingRobotUrl, body, new HttpRequests.OnRequestCallback() {
                @Override
                public void onSuccess(String result) {
                    Log.d(TAG, "onSuccess: " + result);
                }

                @Override
                public void onFail(String failMessage) {
                    Log.d(TAG, "onFail: " + failMessage);
                }

                @Override
                public void onError(String errorMessage) {
                    Log.d(TAG, "onError: " + errorMessage);
                }
            });

        } catch (JSONException e) {
            e.printStackTrace();
        }
    }

}

